@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.65 2003/12/21 17:22:13 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.66.2.2 2003/12/29 09:58:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -295,6 +295,9 @@ font_selection_dialog_response_cb(GtkWidget *dialog, gint response_id,
   gchar *font_name = NULL;
 
   g_return_if_fail(GTK_IS_FONT_SELECTION_DIALOG(dialog));
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   font_selection = GTK_FONT_SELECTION_DIALOG(dialog);
 
   switch (response_id)
@@ -303,6 +306,8 @@ font_selection_dialog_response_cb(GtkWidget *dialog, gint response_id,
       font_name = gtk_font_selection_dialog_get_font_name(font_selection);
       preview_thread_view_font(font_name);
       g_free(font_name);
+
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
     case GTK_RESPONSE_OK:
@@ -319,6 +324,8 @@ font_selection_dialog_response_cb(GtkWidget *dialog, gint response_id,
     }
 
   gtk_widget_destroy(dialog);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -764,8 +771,6 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
     OchushaAsyncBuffer *buffer;
 
     thread_view = bbs_thread_view_new(thread);
-    g_object_ref(G_OBJECT(thread_view));
-    gtk_object_sink(GTK_OBJECT(thread_view));
 
     job = G_NEW0(WorkerJob, 1);
     job_args = G_NEW0(BBSThreadJobArgs, 1);
@@ -780,7 +785,7 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 #endif
 	G_FREE(job_args);
 	G_FREE(job);
-	g_object_unref(G_OBJECT(thread_view));
+	gtk_object_sink(GTK_OBJECT(thread_view));
 
 	BBS_THREAD_UI_UNLOCK;
 	return NULL;
@@ -788,6 +793,7 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 
     setup_for_tab_label_animation(buffer, tab_label);
 
+    info->recent_view = thread_view;
     info->response_source_buffer = buffer;
     info->rendering_done = FALSE;
 
@@ -825,9 +831,9 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 	    G_OBJECT(buffer)->ref_count);
 #endif
       /* öref_count䤹 */
-    g_object_ref(G_OBJECT(buffer));
-    g_object_ref(G_OBJECT(tab_label));
-    g_object_ref(G_OBJECT(thread_view));
+    OCHU_OBJECT_REF(G_OBJECT(buffer));
+    OCHU_OBJECT_REF(G_OBJECT(tab_label));
+    OCHU_OBJECT_REF(G_OBJECT(thread_view));
 #if 0
     fprintf(stderr, "#1: thread_view(%p)->ref_count=%d\n",
 	    thread_view, G_OBJECT(thread_view)->ref_count);
@@ -845,10 +851,7 @@ link_popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
 {
   OchushaApplication *application = data;
   const char *url = gtk_item_factory_popup_data(link_popup_menu_item_factory);
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "link_popup_menu_callback: application=%p, url=\"%s\"(@%p), action=%d\n",
-	  application, url, url, action);
-#endif
+
   switch (action)
     {
     case LINK_POPUP_MENU_OPEN_LINK:
@@ -877,9 +880,6 @@ link_popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
 static void
 link_popup_menu_destructed_cb(gpointer data)
 {
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "link_popup_menu_destructed_cb: url=\"%s\"\n", (char *)data);
-#endif
   G_FREE(data);
 }
 
@@ -898,6 +898,8 @@ response_popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
   ResponsePopupMenuData *menu_data
     = gtk_item_factory_popup_data(response_popup_menu_item_factory);
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   switch (action)
     {
     case RESPONSE_POPUP_MENU_INSERT_BOOKMARK:
@@ -905,17 +907,19 @@ response_popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
 		      menu_data->res_num, (OchushaApplication*)data);
       break;
     }
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 response_popup_menu_destructed_cb(gpointer data)
 {
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "response_popup_menu_destructed_cb: url=\"%s\"\n",
-	  (char *)data);
-#endif
+  MAIN_THREAD_EVENT_CALLBACK();
+
   G_FREE(data);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -925,9 +929,7 @@ link_mouse_over_cb(BBSThreadView *view, GdkEventMotion *event,
 		   OchushaApplication *application)
 {
   GtkStatusbar *statusbar = application->statusbar;
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "link_mouse_over_cb: link=\"%s\"\n", link);
-#endif
+
   if (message_id != 0)
     {
       gtk_statusbar_remove(statusbar, link_field_id, message_id);
@@ -1028,6 +1030,9 @@ ensure_popup_context(BBSThreadView *parent, OchushaBBSThread *thread,
   RendererContext *renderer_context;
   PopupContext *popup_context = g_object_get_qdata(G_OBJECT(parent),
 						   popup_context_id);
+
+  CHECK_THREADS_ENTERED();
+
   if (popup_context != NULL)
     return popup_context;
 
@@ -1218,7 +1223,9 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
     {
       int res_num;
       if (!application->stick_bookmark)
-	return FALSE;
+	{
+	  return FALSE;
+	}
 
       res_num = 0;
       if (event->button == 3 && sscanf(link + 5, "%d", &res_num) == 1)
@@ -1346,9 +1353,11 @@ update_threadlist_entry(OchushaApplication *application,
 
   g_return_if_fail(boardlist != NULL && thread != NULL);
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   update_threadlist_entry_real(application, thread);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 }
 
 
@@ -1356,20 +1365,24 @@ typedef struct _ScrollToMarkArgs
 {
   BBSThreadView *view;
   BBSThreadGUIInfo *info;
+  GtkTextMark *mark;
 } ScrollToMarkArgs;
 
 
 static gboolean
 scroll_to_mark_on_idle(ScrollToMarkArgs *args)
 {
-  gdk_threads_enter();
-  if (args->info->next_mark != NULL)
+  OCHU_THREADS_ENTER();
+
+  if (args->info->next_mark == args->mark
+      && (BBSThreadView *)args->info->recent_view == args->view)
     {
       bbs_thread_view_scroll_to_mark(args->view, args->info->next_mark);
       args->info->next_mark = NULL;
       args->info->scroller_id = 0;
     }
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
   return FALSE;
 }
 
@@ -1385,6 +1398,7 @@ save_initial_thread_view_position(BBSThreadView *view, BBSThreadGUIInfo *info,
   info->next_mark = mark;
   args->view = view;
   args->info = info;
+  args->mark = mark;
   info->scroller_id = g_idle_add_full(G_PRIORITY_HIGH_IDLE + 13,
 				      (GSourceFunc)scroll_to_mark_on_idle,
 				      args, (GDestroyNotify)g_free);
@@ -1402,23 +1416,24 @@ bookmark_clicked_cb(GtkWidget *widget, BBSThreadView *view)
 
   g_return_if_fail(application != NULL && OCHUSHA_IS_BBS_THREAD(thread));
 
-#if 0	/* ̤ɤġġ */
-  if (!application->stick_bookmark)
-    return;
-#endif
-
   info = ensure_bbs_thread_info(thread);
 
   if (info->bookmark_response_number == thread->number_of_responses_read)
     return;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   insert_bookmark(view, thread, thread->number_of_responses_read, application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 bookmark_destroy_cb(GtkWidget *widget, BBSThreadGUIInfo *info)
 {
+  CHECK_THREADS_ENTERED();
+
   if (info->bookmark == widget)
     info->bookmark = NULL;
 #if 0
@@ -1719,7 +1734,8 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 	       _("Updating thread %s@%s board"),
 	       thread->title, thread->board->name);
 
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       if (!application->stick_bookmark)
 	{
 	  insert_bookmark(job_args->view, thread, job_args->start,
@@ -1735,7 +1751,8 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       info->message_id
 	= gtk_statusbar_push(application->statusbar, thread_netstat_id,
 			     default_text_buffer);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
     }
   else
     {
@@ -1743,14 +1760,16 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 	       _("Getting thread %s@%s board"),
 	       thread->title, thread->board->name);
 
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       if (info->message_id != 0)
 	gtk_statusbar_remove(application->statusbar, thread_netstat_id,
 			     info->message_id);
       info->message_id
 	= gtk_statusbar_push(application->statusbar, thread_netstat_id,
 			     default_text_buffer);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
     }
 
   ochusha_bbs_thread_parse_responses(thread, buffer,
@@ -1765,27 +1784,25 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 
   update_threadlist_entry(job_args->application, thread);
 
-  if (job_args->tab_label != NULL)
-    g_object_unref(G_OBJECT(job_args->tab_label));
-
-  g_object_unref(G_OBJECT(job_args->view));
-#if 0
-  fprintf(stderr, "#3: thread_view(%p)->ref_count=%d\n",
-	  job_args->view, G_OBJECT(job_args->view)->ref_count);
-#endif
-
   iconv_close(context.handler.converter);
 
-  g_object_unref(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
+
+  OCHU_THREADS_ENTER();
+
+  if (job_args->tab_label != NULL)
+    OCHU_OBJECT_UNREF(G_OBJECT(job_args->tab_label));
+
+  OCHU_OBJECT_UNREF(G_OBJECT(job_args->view));
 
-  gdk_threads_enter();
   if (info->message_id != 0)
     {
       gtk_statusbar_remove(application->statusbar, thread_netstat_id,
 			   info->message_id);
       info->message_id = 0;
     }
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   BBS_THREAD_UI_LOCK
   {
@@ -1838,7 +1855,7 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 
   context->title_shown = TRUE;
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   if (context->last_read_number == 0 && info->res_num == 0)
     {
@@ -1861,7 +1878,7 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
       bbs_thread_view_scroll_to_mark(view, info->last_read);
     }
 
-  gdk_threads_leave();
+  OCHU_THREADS_LEAVE();
 
   return TRUE;	/* go ahead! */
 }
@@ -1931,13 +1948,14 @@ render_response(OchushaBBSThread *thread, gint number,
 
   if (a_bone && context->transparent_a_bone)
     {
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       goto after_response;
     }
 
   snprintf(buffer, 18, "<RES>%d", number);
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   bbs_thread_view_push_tag(view, context->response_header_tag);
   bbs_thread_view_append_text(view, "\n", 1);
@@ -2087,7 +2105,7 @@ render_response(OchushaBBSThread *thread, gint number,
 	}
     }
 
-  gdk_threads_leave();
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -2138,7 +2156,7 @@ render_broken_response(OchushaBBSThread *thread, gint number,
 
   snprintf(buffer, 13, "\n%d", number);
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   bbs_thread_view_append_text(view, buffer, -1);
   bbs_thread_view_append_text(view, LARGE_COLON, 3);
@@ -2168,7 +2186,7 @@ render_broken_response(OchushaBBSThread *thread, gint number,
 	}
     }
 
-  gdk_threads_leave();
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -2219,13 +2237,16 @@ end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
 	       _("A Bone occurs in thread %s@%s board"),
 	       thread->title, thread->board->name);
 
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       if (info->message_id != 0)
 	gtk_statusbar_remove(context->application->statusbar,
 			     thread_netstat_id, info->message_id);
       info->message_id = gtk_statusbar_push(context->application->statusbar,
 					    thread_netstat_id, message);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
+
       thread->number_of_responses_read = 1;
       /* 0ˤȡɤ߹ߤߤˡå夬ĤäƤΤ̤
        * ˤʤ륿ߥ󥰤Τǡ
@@ -2635,8 +2656,10 @@ popup_expose_event_cb(GtkWidget *widget, GdkEventExpose *event,
 		      PopupContext *popup_context)
 {
   GtkRequisition requisition = { 0, 0 };
-  gtk_widget_size_request(widget, &requisition);
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
+  gtk_widget_size_request(widget, &requisition);
 
 #if DEBUG_GUI_MOST
   fprintf(stderr, "popup_expose_event_cb(widget=%p), w=%d, h=%d\n",
@@ -2685,6 +2708,7 @@ popup_expose_event_cb(GtkWidget *widget, GdkEventExpose *event,
 			popup_context->x_pos, popup_context->y_pos);
     }
 
+  ENTER_MAIN_EVENT_LOOP();
   return FALSE;
 }
 
@@ -2698,9 +2722,14 @@ popup_map_event_cb(GtkWidget *widget, GdkEvent *event,
 		   PopupContext *popup_context)
 {
   GtkRequisition requisition = { 0, 0 };
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_widget_size_request(widget, &requisition);
   fprintf(stderr, "popup_map_event_cb(widget=%p), w=%d, h=%d\n",
 	  widget, requisition.width, requisition.height);
+
+  ENTER_MAIN_EVENT_LOOP();
   return FALSE;
 }
 
@@ -2709,9 +2738,14 @@ static void
 popup_realize_cb(GtkWidget *widget, PopupContext *popup_context)
 {
   GtkRequisition requisition = { 0, 0 };
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_widget_size_request(widget, &requisition);
   fprintf(stderr, "popup_realize_cb(widget=%p), w=%d, h=%d\n",
 	  widget, requisition.width, requisition.height);
+
+  ENTER_MAIN_EVENT_LOOP();
   return;
 }
 #endif
@@ -2827,14 +2861,15 @@ render_popup_response(PopupContext *popup_context,
     }
 
   popup_context->renderer_context.last_rendered_response = 0;
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
   ochusha_bbs_thread_parse_responses(thread, buffer,
 				     response_from - 1, num_responses,
 				     TRUE,
 				     NULL, render_response,
 				     render_broken_response, NULL,
 				     &popup_context->renderer_context);
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   iconv_close(popup_context->renderer_context.handler.converter);
   popup_context->renderer_context.handler.converter = (iconv_t)0;
@@ -2854,6 +2889,8 @@ show_popup(OchushaApplication *application, OchushaBBSThread *thread,
   gint response_to = 0;
   gint num_responses;
 
+  CHECK_THREADS_ENTERED();
+
   popup_context = ensure_popup_context(parent, thread, application);
 
 #if DEBUG_GUI_MOST
@@ -2928,7 +2965,7 @@ popup_delay_timeout(PopupContext *popup_context)
   fprintf(stderr, "popup_delay_timeout(%p)\n", data);
 #endif
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   if (popup_context->url != NULL)
     {
@@ -2942,7 +2979,7 @@ popup_delay_timeout(PopupContext *popup_context)
       result = FALSE;
     }
 
-  gdk_threads_leave();
+  OCHU_THREADS_LEAVE();
 
   return result;
 }
@@ -3036,6 +3073,9 @@ hide_popup_real(PopupContext *popup_context)
   /*
    * MEMO: gdk_threads_enter()줿ĶƤФ롣
    */
+
+  CHECK_THREADS_ENTERED();
+
   if (popup_context->url != NULL)
     {
       G_FREE(popup_context->url);
@@ -3082,7 +3122,7 @@ popup_close_delay_timeout(PopupContext *popup_context)
 	  popup_context);
 #endif
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   if (!popup_context->now_pointed
       && !(popup_context->renderer_context.view != NULL
@@ -3098,7 +3138,7 @@ popup_close_delay_timeout(PopupContext *popup_context)
 
   popup_context->close_delay_id = 0;
 
-  gdk_threads_leave();
+  OCHU_THREADS_LEAVE();
 
   return FALSE;
 }
@@ -3113,6 +3153,8 @@ hide_popup(PopupContext *popup_context)
   OchushaApplication *application
     = popup_context->renderer_context.application;
 
+  CHECK_THREADS_ENTERED();
+
 #if DEBUG_POPUP
   fprintf(stderr, "hide_popup: popup_context=%p\n", popup_context);
 #endif
@@ -3202,9 +3244,9 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
     fprintf(stderr, "* before unref: buffer->ref_count=%d\n",
 	    G_OBJECT(buffer)->ref_count);
 #endif
-    g_object_ref(G_OBJECT(buffer));
-    g_object_ref(G_OBJECT(tab_label));
-    g_object_ref(G_OBJECT(view));
+    OCHU_OBJECT_REF(G_OBJECT(buffer));
+    OCHU_OBJECT_REF(G_OBJECT(tab_label));
+    OCHU_OBJECT_REF(G_OBJECT(view));
 #if 0
     fprintf(stderr, "#2: thread_view(%p)->ref_count=%d\n",
 	    view, G_OBJECT(view)->ref_count);
@@ -3219,7 +3261,7 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 	fprintf(stderr, "* before unref: old_buffer->ref_count=%d\n",
 		G_OBJECT(old_buffer)->ref_count);
 #endif
-	g_object_unref(G_OBJECT(old_buffer));
+	OCHU_OBJECT_UNREF(G_OBJECT(old_buffer));
       }
   }
 
@@ -3233,7 +3275,9 @@ void
 go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
   BBSThreadView *view;
+
   g_return_if_fail(widget != NULL);
+
   view = BBS_THREAD_VIEW(widget);
   bbs_thread_view_scroll_to_start(view);
 }
@@ -3243,7 +3287,9 @@ void
 go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
   BBSThreadView *view;
+
   g_return_if_fail(widget != NULL);
+
   view = BBS_THREAD_VIEW(widget);
   bbs_thread_view_scroll_to_end(view);
 }
