@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.17 2003/12/20 04:21:27 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.17.2.1 2003/12/29 09:58:14 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -72,6 +72,12 @@ typedef struct _BBSThreadGUIInfo
   /* ᥤ򥹥ɽϤʸȤɽ뤫ɤ */
   ThreadViewMailtoMode show_mailto_mode;
 
+  /*
+   * Ƥ륹ΤΤBBSThreadView
+   * last_read/next_markϤviewФΡ
+   */
+  GtkWidget *recent_view;
+
   /* ǽο쥹Ƭդޡ */
   GtkTextMark *last_read;
 
