@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.30 2003/12/21 02:23:13 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.31.2.1 2003/12/29 09:04:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -500,25 +500,12 @@ bbs_thread_view_init(BBSThreadView *view)
 static void
 bbs_thread_view_finalize(GObject *object)
 {
-#if 0
   BBSThreadView *view = BBS_THREAD_VIEW(object);
+
+#if 0
   fprintf(stderr, "bbs_thread_view_finalize(%p)\n", object);
 #endif
 
-  if (G_OBJECT_CLASS(parent_class)->finalize)
-    (*G_OBJECT_CLASS(parent_class)->finalize)(object);
-}
-
-
-static void
-bbs_thread_view_destroy(GtkObject *object)
-{
-  BBSThreadView *view = BBS_THREAD_VIEW(object);
-
-#if 0
-  fprintf(stderr, "bbs_thread_view_destroy(%p)\n", object);
-#endif
-
   if (view->text_buffer != NULL)
     {
       g_object_unref(G_OBJECT(view->text_buffer));
@@ -542,6 +529,20 @@ bbs_thread_view_destroy(GtkObject *object)
       view->child_table = NULL;
     }
 
+  if (G_OBJECT_CLASS(parent_class)->finalize)
+    (*G_OBJECT_CLASS(parent_class)->finalize)(object);
+}
+
+
+static void
+bbs_thread_view_destroy(GtkObject *object)
+{
+  BBSThreadView *view = BBS_THREAD_VIEW(object);
+
+#if 0
+  fprintf(stderr, "bbs_thread_view_destroy(%p)\n", object);
+#endif
+
   if (view->ibeam_cursor != NULL)
     {
       gdk_cursor_unref(view->ibeam_cursor);
@@ -677,6 +678,8 @@ enter_notify_event_cb(GtkWidget *widget, GdkEventCrossing *event,
 {
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view), FALSE);
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
 #if DEBUG_WIDGET_MOST
   fprintf(stderr, "bbs_thread_view.c: enter_notify_event_cb\n");
 #endif
@@ -686,6 +689,8 @@ enter_notify_event_cb(GtkWidget *widget, GdkEventCrossing *event,
 		0,
 		event);
 
+  ENTER_MAIN_EVENT_LOOP();
+
   return FALSE;
 }
 
@@ -696,6 +701,8 @@ leave_notify_event_cb(GtkWidget *widget, GdkEventCrossing *event,
 {
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view), FALSE);
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
 #if DEBUG_WIDGET_MOST
   fprintf(stderr, "bbs_thread_view.c: leave_notify_event_cb\n");
 #endif
@@ -707,6 +714,8 @@ leave_notify_event_cb(GtkWidget *widget, GdkEventCrossing *event,
 		0,
 		event);
 
+  ENTER_MAIN_EVENT_LOOP();
+
   return FALSE;
 }
 
@@ -720,12 +729,17 @@ motion_notify_event_cb(GtkTextView *text_view, GdkEventMotion *event,
   g_return_val_if_fail(GTK_IS_TEXT_VIEW(text_view)
 		       && event->type == GDK_MOTION_NOTIFY, FALSE);
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (text_view_get_iter_at_link_tag_from_event(text_view, &iter,
 						(GdkEventAny *)event))
     {
       gint start_offset = gtk_text_iter_get_offset(&iter);
       if (start_offset == bbs_thread_view->last_offset)
-	return FALSE;
+	{
+	  ENTER_MAIN_EVENT_LOOP();
+	  return FALSE;
+	}
 
       if (bbs_thread_view->last_offset != -1)
 	emit_link_mouse_out(bbs_thread_view, (GdkEventAny *)event);
@@ -736,6 +750,8 @@ motion_notify_event_cb(GtkTextView *text_view, GdkEventMotion *event,
   else if (bbs_thread_view->last_offset != -1)
     emit_link_mouse_out(bbs_thread_view, (GdkEventAny *)event);
 
+  ENTER_MAIN_EVENT_LOOP();
+
   return FALSE;
 }
 
@@ -821,6 +837,8 @@ button_press_event_cb(GtkTextView *text_view, GdkEventButton *event,
 				       (gconstpointer)start_offset)
 	: NULL;
 
+      MAIN_THREAD_EVENT_CALLBACK();
+
       g_signal_emit(G_OBJECT(bbs_thread_view),
 		    bbs_thread_view_signals[LINK_MOUSE_PRESS_SIGNAL],
 		    0,
@@ -828,6 +846,8 @@ button_press_event_cb(GtkTextView *text_view, GdkEventButton *event,
 		    bbs_thread_view->thread,
 		    link,
 		    &handled);
+
+      ENTER_MAIN_EVENT_LOOP();
       return TRUE;
     }
 
@@ -854,6 +874,8 @@ button_release_event_cb(GtkTextView *text_view, GdkEventButton *event,
 				       (gconstpointer)start_offset)
 	: NULL;
 
+      MAIN_THREAD_EVENT_CALLBACK();
+
       g_signal_emit(G_OBJECT(bbs_thread_view),
 		    bbs_thread_view_signals[LINK_MOUSE_RELEASE_SIGNAL],
 		    0,
@@ -861,7 +883,8 @@ button_release_event_cb(GtkTextView *text_view, GdkEventButton *event,
 		    bbs_thread_view->thread,
 		    link,
 		    &handled);
-/*      return TRUE; */
+
+      ENTER_MAIN_EVENT_LOOP();
     }
 
   return FALSE;
@@ -904,6 +927,8 @@ bbs_thread_view_clear(BBSThreadView *view)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
+  CHECK_THREADS_ENTERED();
+
   gtk_text_buffer_get_start_iter(view->text_buffer, &view->iter);
   gtk_text_buffer_get_end_iter(view->text_buffer, &end_iter);
 
@@ -994,6 +1019,8 @@ bbs_thread_view_append_text(BBSThreadView *view, const gchar *text, int len)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && text != NULL);
 
+  CHECK_THREADS_ENTERED();
+
   args.start = &start;
   args.end = &view->iter;
   args.buffer = view->text_buffer;
@@ -1090,6 +1117,8 @@ bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && GTK_IS_WIDGET(widget));
 
+  CHECK_THREADS_ENTERED();
+
   vbox = gtk_vbox_new(FALSE, 0);
   hbox = gtk_hbox_new(FALSE, 0);
 
@@ -1151,6 +1180,8 @@ bbs_thread_view_insert_widget_at_offset(BBSThreadView *view, GtkWidget *widget,
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && GTK_IS_WIDGET(widget));
 
+  CHECK_THREADS_ENTERED();
+
   vbox = gtk_vbox_new(FALSE, 0);
   hbox = gtk_hbox_new(FALSE, 0);
 
@@ -1215,6 +1246,8 @@ bbs_thread_view_remove_widget(BBSThreadView *view, GtkWidget *widget)
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
   g_return_if_fail(GTK_IS_WIDGET(widget));
 
+  CHECK_THREADS_ENTERED();
+
   anchor_offset = (guint)g_hash_table_lookup(view->child_table, widget);
   g_return_if_fail(anchor_offset != 0);
 
@@ -1337,6 +1370,8 @@ bbs_thread_view_scroll_to_start(BBSThreadView *view)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
+  CHECK_THREADS_ENTERED();
+
   buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(view));
   g_return_if_fail(buffer != NULL);
 
@@ -1356,6 +1391,8 @@ bbs_thread_view_scroll_to_end(BBSThreadView *view)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
+  CHECK_THREADS_ENTERED();
+
   buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(view));
   g_return_if_fail(buffer != NULL);
 
@@ -1376,6 +1413,8 @@ bbs_thread_view_scroll_to_offset(BBSThreadView *view, gint offset)
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_buffer != NULL,
 		       0);
 
+  CHECK_THREADS_ENTERED();
+
   gtk_text_view_place_cursor_onscreen(GTK_TEXT_VIEW(view));
   gtk_text_buffer_get_iter_at_mark(view->text_buffer, &iter,
 				   gtk_text_buffer_get_insert(view->text_buffer));
@@ -1398,6 +1437,8 @@ bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && mark != NULL);
 
+  CHECK_THREADS_ENTERED();
+
   buffer = gtk_text_mark_get_buffer(mark);
   g_return_if_fail(buffer != NULL);
 
