@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.45 2003/12/24 03:41:41 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.47.2.1 2003/12/29 09:04:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -648,6 +648,8 @@ static void
 text_search_window_response_cb(TextSearchWindow *window, gint response_id,
 			       OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   switch (response_id)
     {
     case GTK_RESPONSE_DELETE_EVENT:
@@ -660,8 +662,13 @@ text_search_window_response_cb(TextSearchWindow *window, gint response_id,
 	threadlist_view_set_being_searched(search_query_data.last_view, FALSE);
       search_query_data.last_view = NULL;
       gtk_widget_hide(GTK_WIDGET(window));
+
+      ENTER_MAIN_EVENT_LOOP();
+
       return;
     }
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -712,6 +719,8 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
   gboolean result;
   gchar *normalized_key;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (search_query_data.key != NULL)
     G_FREE(search_query_data.key);
 
@@ -760,6 +769,8 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
   else
     result = do_search_on_current_threadlist(application, TRUE);
 
+  ENTER_MAIN_EVENT_LOOP();
+
   return result;
 }
 
@@ -771,7 +782,15 @@ text_search_window_find_next_cb(TextSearchWindow *window, const gchar *key,
 				gboolean use_regexp,
 				OchushaApplication *application)
 {
-  return do_search_on_current_threadlist(application, FALSE);
+  gboolean result;
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
+  result = do_search_on_current_threadlist(application, FALSE);
+
+  ENTER_MAIN_EVENT_LOOP();
+
+  return result;
 }
 
 
@@ -856,12 +875,12 @@ terminate_threadlist_search(OchushaApplication *application,
   TextSearchWindow *window;
   window = TEXT_SEARCH_WINDOW(application->threadlist_search_window);
   if (window != NULL)
-    g_object_ref(G_OBJECT(window));
+    OCHU_OBJECT_REF(G_OBJECT(window));
 
   if (window != NULL)
     {
       text_search_window_response(window, GTK_RESPONSE_CANCEL);
-      g_object_unref(G_OBJECT(window));
+      OCHU_OBJECT_UNREF(G_OBJECT(window));
     }
 }
 
@@ -916,12 +935,17 @@ filter_toggled_cb(GtkToggleButton *toggle_button,
   if (info->enable_filter == gtk_toggle_button_get_active(toggle_button))
     return;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   info->enable_filter = !info->enable_filter;
 
   gtk_toggle_button_set_active(toggle_button, info->enable_filter);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
   redraw_threadlist_view(application, board);
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -943,6 +967,7 @@ item_view_required_cb(PanedNotebook *paned_notebook, gpointer item,
 		      OchushaApplication *application)
 {
   OchushaBulletinBoard *board;
+
   if (!OCHUSHA_IS_BULLETIN_BOARD(item))
     {
       *tab_label = NULL;
@@ -999,7 +1024,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    * ȤäƤidleؿλŻλƤȤȤˤʤΤǡ
    * פ
    */
-  g_object_ref(G_OBJECT(item_view));
+  OCHU_OBJECT_REF(G_OBJECT(item_view));
 
   /*
    * MEMO: Ĥ褦ȤƤ륹Ρsubject.txtɤ߹ߡפ
@@ -1007,13 +1032,11 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    */
   if (buffer != NULL)
     {
-      gdk_threads_leave();
-
+      OCHU_THREADS_LEAVE();
       ochusha_async_buffer_suspend(buffer);
       ochusha_async_buffer_terminate(buffer);
       ochusha_async_buffer_resume(buffer);
-
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
     }
 
   if (item_view != NULL)
@@ -1031,7 +1054,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
     }
 
   if (buffer != NULL)
-    g_object_unref(G_OBJECT(buffer));
+    OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 
   if (info->message_id != 0)
     {
@@ -1124,6 +1147,7 @@ boardlist_read_category_element_cb(OchushaBBSTable *table,
 				   OchushaApplication *application)
 {
   BoardCategoryGUIInfo *info = ensure_board_category_info(category);
+
   info->expanded = ochusha_utils_get_attribute_boolean(category_attributes,
 						       "expanded");
   return;
@@ -1237,17 +1261,18 @@ boardlist_write_category_element_cb(OchushaBBSTable *table,
 
 
 #define OUTPUT_BOARD_ATTRIBUTE_STRING(gzfile, board, attribute)		\
-  do {									\
-    if ((board)->attribute != NULL)					\
-      {									\
-	gchar *text = g_markup_escape_text((board)->attribute, -1);	\
-	gzprintf(gzfile,						\
-		"        <attribute name=\"" #attribute "\">\n"		\
-		"          <string>%s</string>\n"			\
-		"        </attribute>\n", text);			\
-	g_free(text);							\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      if ((board)->attribute != NULL)					\
+	{								\
+	  gchar *text = g_markup_escape_text((board)->attribute, -1);	\
+	  gzprintf(gzfile,						\
+		   "        <attribute name=\"" #attribute "\">\n"	\
+		   "          <string>%s</string>\n"			\
+		   "        </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 static void
@@ -1317,6 +1342,7 @@ category_expanded_cb(BoardlistView *view, OchushaBoardCategory *category,
 		     OchushaApplication *application)
 {
   BoardCategoryGUIInfo *info = ensure_board_category_info(category);
+
   info->expanded = TRUE;
   if (application->expand_only_one_category)
     {
@@ -1472,9 +1498,11 @@ build_boardlist(WorkerThread *employee, gpointer args)
 					process_board_move,
 					application))
     {
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       setup_boardlist(application);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
 
       ochusha_bbs_table_write_boardlist_xml(table, &application->config,
 					    application->session_subdir);
@@ -1485,7 +1513,7 @@ build_boardlist(WorkerThread *employee, gpointer args)
 
  cleanup_before_return:
   if (buffer != NULL)
-    g_object_unref(G_OBJECT(buffer));
+    OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 
   if (pthread_mutex_unlock(&board_list_lock) != 0)
     {
@@ -1523,7 +1551,11 @@ setup_boardlist(OchushaApplication *application)
 static void
 make_new_thread_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   make_new_thread(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1531,14 +1563,22 @@ static void
 open_board_properties_button_cb(GtkWidget *widget,
 				OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   open_current_board_properties(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 refresh_board_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   refresh_current_threadlist(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1546,7 +1586,11 @@ static void
 start_threadlist_search_button_cb(GtkWidget *widget,
 				  OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   start_current_threadlist_search(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1558,6 +1602,9 @@ new_thread_dialog_response_cb(GtkWidget *dialog, gint response_id,
   gboolean result;
   guint message_id = (guint)g_object_get_data(G_OBJECT(dialog),
 					      "statusbar_message");
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (message_id != 0)
     {
       gtk_statusbar_remove(application->statusbar,
@@ -1667,6 +1714,8 @@ new_thread_dialog_response_cb(GtkWidget *dialog, gint response_id,
     ochusha_open_url(application,
 		     ochusha_bulletin_board_get_base_url(board),
 		     FALSE, TRUE);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
