@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.16 2003/12/16 14:50:33 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.17 2003/12/29 05:21:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -777,9 +777,13 @@ boardlist_view_do_on_selection(BoardlistView *view, gint what_to_do)
   fprintf(stderr, "boardlist_view_do_on_selection: view=%p what_to_do=%d\n",
 	  view, what_to_do);
 #endif
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_tree_selection_selected_foreach(view->selection,
 			(GtkTreeSelectionForeachFunc)do_on_selection_helper,
 			&args);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -897,6 +901,8 @@ tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
   gpointer data = NULL;
   gboolean result = FALSE;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   view->last_event_x = event->x;
   view->last_event_y = event->y;
   view->last_event_button = event->button;
@@ -955,6 +961,8 @@ tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
     }
 
  done:
+  ENTER_MAIN_EVENT_LOOP();
+
   if (path != NULL)
     gtk_tree_path_free(path);
 
@@ -966,6 +974,8 @@ static gboolean
 tree_view_button_release_event_cb(GtkWidget *widget, GdkEventButton *event,
 				  BoardlistView *view)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (view != NULL)
     {
       view->last_event_x = event->x;
@@ -973,6 +983,7 @@ tree_view_button_release_event_cb(GtkWidget *widget, GdkEventButton *event,
       view->last_event_button = event->button;
     }
 
+  ENTER_MAIN_EVENT_LOOP();
   return FALSE;
 }
 
