@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.81 2003/12/24 03:41:41 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.83.2.2 2003/12/29 09:58:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -333,18 +333,18 @@ threadlist_read_thread_element_cb(OchushaBulletinBoard *board,
 
 
 #define OUTPUT_THREAD_ATTRIBUTE_STRING(gzfile, thread, attribute)	\
-  do {									\
-    if ((thread)->attribute != NULL)					\
-      {									\
-	gchar *text = g_markup_escape_text((thread)->attribute, -1);	\
-	gzprintf(gzfile,						\
-		"      <attribute name=\"" #attribute	"\">\n"		\
-		"        <string>%s</string>\n"				\
-		"      </attribute>\n", text);				\
-	g_free(text);							\
-      }									\
-  } while (0)
-
+  do									\
+    {									\
+      if ((thread)->attribute != NULL)					\
+	{								\
+	  gchar *text = g_markup_escape_text((thread)->attribute, -1);	\
+	  gzprintf(gzfile,						\
+		   "      <attribute name=\"" #attribute	"\">\n"	\
+		   "        <string>%s</string>\n"			\
+		   "      </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 static void
@@ -498,11 +498,15 @@ interactive_search_cb(ThreadlistView *view,
 		      ThreadlistSearchAction search_action,
 		      OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (search_action != THREADLIST_SEARCH_ACTION_TERMINATE)
     advance_threadlist_search(application, view, search_action);
   else
     terminate_threadlist_search(application, view);
 
+  ENTER_MAIN_EVENT_LOOP();
+
   return TRUE;
 }
 
@@ -839,10 +843,10 @@ open_bulletin_board(OchushaApplication *application,
 				    tab_label);
 
     /* Ȥޤǳ */
-    g_object_ref(G_OBJECT(tab_label));
-    g_object_ref(G_OBJECT(view));
+    OCHU_OBJECT_REF(G_OBJECT(tab_label));
+    OCHU_OBJECT_REF(G_OBJECT(view));
     if (info->threadlist_source_buffer != NULL)
-      g_object_ref(G_OBJECT(info->threadlist_source_buffer));
+      OCHU_OBJECT_REF(G_OBJECT(info->threadlist_source_buffer));
 #if DEBUG_WIDGET
     fprintf(stderr, "#1: threadlist_view->ref_count=%d\n",
 	    G_OBJECT(view)->ref_count);
@@ -937,7 +941,8 @@ open_thread_view(WorkerThread *employee, gpointer job_args)
 
     if (thread != NULL)
       {
-	gdk_threads_enter();
+	OCHU_THREADS_ENTER();
+
 	board_view = (PanedNotebook *)paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), board);
 
 	/* TODO:
@@ -948,7 +953,8 @@ open_thread_view(WorkerThread *employee, gpointer job_args)
 
 	if (board_view != NULL)
 	  paned_notebook_open_item_view(board_view, thread, args->in_tab);
-	gdk_threads_leave();
+
+	OCHU_THREADS_LEAVE();
       }
   }
   THREAD_LIST_UNLOCK;
@@ -1027,16 +1033,16 @@ refresh_threadlist_view(OchushaApplication *application,
       
     info->is_busy = TRUE;
     /* λޤǳ */
-    g_object_ref(G_OBJECT(info->threadlist_source_buffer));
-    g_object_ref(G_OBJECT(tab_label));
-    g_object_ref(G_OBJECT(threadlist_view));
+    OCHU_OBJECT_REF(G_OBJECT(info->threadlist_source_buffer));
+    OCHU_OBJECT_REF(G_OBJECT(tab_label));
+    OCHU_OBJECT_REF(G_OBJECT(threadlist_view));
 #if DEBUG_WIDGET
     fprintf(stderr, "#2: threadlist_view->ref_count=%d\n",
 	    G_OBJECT(threadlist_view)->ref_count);
 #endif
     commit_job(job);
 
-    g_object_unref(G_OBJECT(old_buffer));
+    OCHU_OBJECT_UNREF(G_OBJECT(old_buffer));
   }
   THREAD_LIST_UNLOCK;
 }
@@ -1101,9 +1107,9 @@ redraw_threadlist_view(OchushaApplication *application,
 
     info->is_busy = TRUE;
     /* λޤǳ */
-    g_object_ref(G_OBJECT(info->threadlist_source_buffer));
-    g_object_ref(G_OBJECT(tab_label));
-    g_object_ref(G_OBJECT(threadlist_view));
+    OCHU_OBJECT_REF(G_OBJECT(info->threadlist_source_buffer));
+    OCHU_OBJECT_REF(G_OBJECT(tab_label));
+    OCHU_OBJECT_REF(G_OBJECT(threadlist_view));
 #if DEBUG_WIDGET
     fprintf(stderr, "#3: threadlist_view->ref_count=%d\n",
 	    G_OBJECT(threadlist_view)->ref_count);
@@ -1195,12 +1201,14 @@ open_kako_thread_view(WorkerThread *employee, gpointer job_args)
 
     if (thread != NULL)
       {
-	gdk_threads_enter();
+	OCHU_THREADS_ENTER();
+
 	board_view = (PanedNotebook *)paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), board);
 
 	if (board_view != NULL)
 	  paned_notebook_open_item_view(board_view, thread, args->in_tab);
-	gdk_threads_leave();
+
+	OCHU_THREADS_LEAVE();
       }
   }
   THREAD_LIST_UNLOCK;
@@ -1260,7 +1268,7 @@ each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
 	  && ((info->view_flags & BBS_THREAD_HIDDEN) == 0
 	      || !args->application->hide_hidden_threads)))
     {
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
 
       threadlist_view_append_thread(view, thread, info->num_shown,
 				    (MAX(thread->number_of_responses_on_server,
@@ -1269,7 +1277,8 @@ each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
 				    info->view_rank, args->number_of_threads);
       update_threadlist_entry_style(args->application, view, thread);
 
-      gdk_threads_leave();
+      OCHU_THREADS_LEAVE();
+
       args->last_thread = thread;
       if (update_condition)
 	info->view_ignored++;
@@ -1332,7 +1341,7 @@ show_threadlist(WorkerThread *employee, gpointer args)
       goto finish_job;
     }
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
 
   if (job_args->increment_ignored)
     {
@@ -1348,13 +1357,15 @@ show_threadlist(WorkerThread *employee, gpointer args)
     }
   if (!threadlist_view_open(view))
     {
-      gdk_threads_leave();
+      OCHU_THREADS_LEAVE();
+
 #if DEBUG_GUI_MOST
       fprintf(stderr, "thread list is now being updated by another thread.\n");
 #endif
       goto finish_job;
     }
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   if (!ochusha_bulletin_board_refresh_threadlist(board, buffer,
 						 each_thread_cb, &cb_args))
@@ -1364,15 +1375,21 @@ show_threadlist(WorkerThread *employee, gpointer args)
       fprintf(stderr, "Broken thread list (subject.txt) for %s\n", name);
       G_FREE(name);
 #endif
-      gdk_threads_enter();
+
+      OCHU_THREADS_ENTER();
+
       threadlist_view_close(view, NULL);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
+
       goto finish_job;
     }
   
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   threadlist_view_close(view, cb_args.last_thread);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
  finish_job:
 #if DEBUG_ASYNC_BUFFER_MOST
@@ -1382,14 +1399,16 @@ show_threadlist(WorkerThread *employee, gpointer args)
 	  G_OBJECT(buffer)->ref_count);
 #endif
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   if (info->message_id != 0)
     {
       gtk_statusbar_remove(application->statusbar, threadlist_netstat_id,
 			   info->message_id);
       info->message_id = 0;
     }
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   THREAD_LIST_LOCK
   {
@@ -1409,14 +1428,16 @@ show_threadlist(WorkerThread *employee, gpointer args)
   }
   THREAD_LIST_UNLOCK;
 
-  gdk_threads_enter();
-  g_object_unref(G_OBJECT(view));	/* ⤦ʤʤäƤɤ */
+  OCHU_THREADS_ENTER();
+
+  OCHU_OBJECT_UNREF(G_OBJECT(view));	/* ⤦ʤʤäƤɤ */
   if (job_args->tab_label != NULL)
-    g_object_unref(G_OBJECT(job_args->tab_label));
-  gdk_threads_leave();
+    OCHU_OBJECT_UNREF(G_OBJECT(job_args->tab_label));
+
+  OCHU_THREADS_LEAVE();
 
   if (buffer != NULL)
-    g_object_unref(G_OBJECT(buffer));
+    OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 
   G_FREE(args);
 }
@@ -1656,7 +1677,8 @@ thread_title_popup_timeout(gpointer data)
 	  title_popup_x_pos, title_popup_y_pos, popup_thread, data);
 #endif
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   if (data == popup_thread)
     {
       THREAD_LIST_LOCK
@@ -1672,7 +1694,8 @@ thread_title_popup_timeout(gpointer data)
 
       result = FALSE;
     }
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   return result;
 }
@@ -1717,6 +1740,7 @@ item_view_required_cb(PanedNotebook *paned_notebook,
 		      OchushaApplication *application)
 {
   GtkWidget *thread_view;
+
   *tab_label = get_tab_label(thread->title);
 
   thread_view = open_bbs_thread(application, thread, ICON_LABEL(*tab_label));
@@ -1756,8 +1780,13 @@ free_response_source_buffer(OchushaBBSThread *thread, gpointer unused)
 #endif
   if (info->response_source_buffer != NULL)
     {
-      g_object_unref(G_OBJECT(info->response_source_buffer));
+      OCHU_OBJECT_UNREF(G_OBJECT(info->response_source_buffer));
       info->response_source_buffer = NULL;
+      info->res_num = 0;
+      info->num_shown = 0;
+      info->last_read = NULL;
+      info->next_mark = NULL;
+      info->bookmark = NULL;
     }
 }
 
@@ -1777,6 +1806,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
   g_return_if_fail(GTK_IS_WIDGET(item_view));
 
   info = ensure_bbs_thread_info(thread);
+  info->recent_view = NULL;
   buffer = info->response_source_buffer;
 
   /*
@@ -1800,7 +1830,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    * ȤäƤidleؿλŻλƤȤȤˤʤΤǡ
    * פ
    */
-  g_object_ref(G_OBJECT(item_view));
+  OCHU_OBJECT_REF(G_OBJECT(item_view));
 
 
   /*
@@ -1809,13 +1839,11 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    */
   if (buffer != NULL)
     {
-      gdk_threads_leave();
-
+      OCHU_THREADS_LEAVE();
       ochusha_async_buffer_suspend(buffer);
       ochusha_async_buffer_terminate(buffer);
       ochusha_async_buffer_resume(buffer);
-
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
     }
 
   threadlist_view = gtk_bin_get_child(GTK_BIN(paned_notebook->selector));
@@ -1871,7 +1899,6 @@ item_view_closed_cb(PanedNotebook *paned_notebook, OchushaBBSThread *thread,
 #if DEBUG_GUI_MOST
   fprintf(stderr, "closed: thread=%p, item_view=%p\n", thread, item_view);
 #endif
-
   delayed_g_object_unref(G_OBJECT(item_view));
 
   free_response_source_buffer(thread, NULL);
@@ -1887,6 +1914,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
   ThreadlistView *threadlist_view;
   OchushaBBSThread *thread;
   BBSThreadGUIInfo *info;
+
 #if DEBUG_GUI_MOST
   fprintf(stderr, "bulletin_board_ui.c: page_switched_cb\n");
 #endif
@@ -1927,7 +1955,9 @@ page_switched_cb(PanedNotebook *paned_notebook,
   scrolled_window = paned_notebook_get_selector(paned_notebook);
   thread = paned_notebook_get_item(paned_notebook, new_page);
   if (scrolled_window == NULL || thread == NULL)
-    return;
+    {
+      return;
+    }
 
   threadlist_view
     = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
@@ -2061,7 +2091,8 @@ background_write_response(WorkerThread *employee, gpointer job_args)
 	   && reverse_strpbrk(response.name, "0123456789") == NULL);
       GtkWidget *notebook;
 
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       if (message_id != 0)
 	{
 	  gtk_statusbar_remove(args->application->statusbar,
@@ -2133,14 +2164,16 @@ background_write_response(WorkerThread *employee, gpointer job_args)
 	}
 
       gtk_widget_destroy(args->dialog);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
     }
   else
     {
       snprintf(message, 4096, _("Posting to %s@%s board failed."),
 	       args->thread->title, args->thread->board->name);
 
-      gdk_threads_enter();
+      OCHU_THREADS_ENTER();
+
       if (message_id != 0)
 	{
 	  gtk_statusbar_remove(args->application->statusbar,
@@ -2155,7 +2188,8 @@ background_write_response(WorkerThread *employee, gpointer job_args)
 		       ochusha_bbs_thread_get_url_to_post_response(args->thread),
 		       FALSE, TRUE);
       gtk_widget_show_all(args->dialog);
-      gdk_threads_leave();
+
+      OCHU_THREADS_LEAVE();
     }
 
   G_FREE(args->name);
@@ -2176,6 +2210,8 @@ write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
   const gchar *mailto;
   gchar *message;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (response_id != GTK_RESPONSE_OK)
     {
       guint message_id = (guint)g_object_get_data(G_OBJECT(write_dialog),
@@ -2187,6 +2223,8 @@ write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
 	  g_object_set_data(G_OBJECT(write_dialog), "status_message", NULL);
 	}
       gtk_widget_destroy(write_dialog);
+
+      ENTER_MAIN_EVENT_LOOP();
       return;
     }
 
@@ -2216,10 +2254,12 @@ write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
 
       commit_job(job);
 
+      ENTER_MAIN_EVENT_LOOP();
       return;
     }
 
-  G_FREE(message);
+  if (message != NULL)
+    G_FREE(message);
 }
 
 
@@ -2295,14 +2335,22 @@ write_response_button_cb(GtkWidget *widget, OchushaApplication *application)
 static void
 select_font_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   select_thread_view_font(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 refresh_thread_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   refresh_current_thread(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2310,6 +2358,8 @@ static void
 text_search_window_response_cb(TextSearchWindow *window, gint response_id,
 			       OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   switch (response_id)
     {
     case GTK_RESPONSE_DELETE_EVENT:
@@ -2324,11 +2374,15 @@ text_search_window_response_cb(TextSearchWindow *window, gint response_id,
 	  bbs_thread_view_invalidate_search_result(BBS_THREAD_VIEW(application->last_search_target_widget));
 	  application->last_search_target_widget = NULL;
 	}
+
+      ENTER_MAIN_EVENT_LOOP();
       return;
     }
 
   fprintf(stderr, "text_search_window_response_cb: unknown response(%d)\n",
 	  response_id);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2340,6 +2394,10 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
 				    OchushaApplication *application)
 {
   GtkWidget *widget;
+  gboolean result;
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   get_current_thread(application, &widget, NULL, NULL);
 
   if (application->last_search_target_widget != widget)
@@ -2351,12 +2409,20 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
     }
 
   if (widget == NULL)
-    return FALSE;
+    {
+      ENTER_MAIN_EVENT_LOOP();
+      return FALSE;
+    }
 
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(widget), FALSE);
-  return bbs_thread_view_find(
+
+  result = bbs_thread_view_find(
 		BBS_THREAD_VIEW(application->last_search_target_widget),
 		key, direction, enable_wrap, match_case, use_regexp);
+
+  ENTER_MAIN_EVENT_LOOP();
+
+  return result;
 }
 
 
@@ -2368,14 +2434,24 @@ text_search_window_find_next_cb(TextSearchWindow *window, const gchar *key,
 				OchushaApplication *application)
 {
   GtkWidget *widget;
+  gboolean result;
+
+  MAIN_THREAD_EVENT_CALLBACK();
 
   get_current_thread(application, &widget, NULL, NULL);
 
   if (application->last_search_target_widget == widget)
     {
       if (widget == NULL)
-	return FALSE;
-      return bbs_thread_view_find_next(BBS_THREAD_VIEW(widget));
+	{
+	  ENTER_MAIN_EVENT_LOOP();
+	  return FALSE;
+	}
+
+      result = bbs_thread_view_find_next(BBS_THREAD_VIEW(widget));
+
+      ENTER_MAIN_EVENT_LOOP();
+      return result;
     }
 
   if (application->last_search_target_widget != NULL)
@@ -2383,10 +2459,16 @@ text_search_window_find_next_cb(TextSearchWindow *window, const gchar *key,
   application->last_search_target_widget = widget;
 
   if (widget == NULL)
-    return FALSE;
-  return bbs_thread_view_find(
+    {
+      ENTER_MAIN_EVENT_LOOP();
+      return FALSE;
+    }
+  result = bbs_thread_view_find(
 		BBS_THREAD_VIEW(application->last_search_target_widget),
 		key, direction, enable_wrap, match_case, use_regexp);
+
+  ENTER_MAIN_EVENT_LOOP();
+  return result;
 }
 
 
@@ -2428,7 +2510,11 @@ static void
 start_thread_search_button_cb(GtkWidget *widget,
 			      OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   start_thread_search(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2447,7 +2533,11 @@ jump_to_bookmark_of_current_thread(OchushaApplication *application)
 static void
 jump_to_bookmark_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   jump_to_bookmark_of_current_thread(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2466,7 +2556,11 @@ go_to_the_last_response_of_current_thread(OchushaApplication *application)
 static void
 go_to_bottom_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   go_to_the_last_response_of_current_thread(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2485,7 +2579,11 @@ go_to_the_first_response_of_current_thread(OchushaApplication *application)
 static void
 go_to_top_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   go_to_the_first_response_of_current_thread(application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
