@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.12 2003/12/24 03:41:41 fuyu Exp $
+ * $Id: main.c,v 1.13.2.1 2003/12/29 09:04:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -34,6 +34,7 @@
 #include "worker.h"
 #include "utils.h"
 
+#define _OCHUSHA_MAIN_C_
 #include "ochusha_ui.h"
 #include "session.h"
 #include "xsmp.h"
@@ -58,6 +59,14 @@
 #define MAXIMUM_NUM_THREADS	32
 
 
+#if DEBUG_GDK_LOCK
+pthread_t volatile last_lock_owner = NULL;
+volatile const char *last_file;
+volatile int last_line;
+pthread_t main_thread = NULL;
+#endif
+
+
 int
 main(int argc, char *argv[])
 {
@@ -185,6 +194,10 @@ main(int argc, char *argv[])
   initialize_default_entity_dictionary();
   initialize_common_converters();
 
+#if DEBUG_GDK_LOCK
+  main_thread = pthread_self();
+#endif
+
   initialize_worker(INITIAL_NUM_THREADS, MAXIMUM_NUM_THREADS);
 
   resource_file = ochusha_config_find_file(&application->config,
@@ -213,7 +226,9 @@ main(int argc, char *argv[])
 
   ochusha_init_application(application);
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
+  ENTER_MAIN_EVENT_LOOP();
   gtk_main();
 
 #if TRACE_MEMORY_USAGE
@@ -221,15 +236,20 @@ main(int argc, char *argv[])
     gtk_widget_destroy(GTK_WIDGET(application->top_level));
 #endif
 
+#if 0
+  MAIN_THREAD_EVENT_CALLBACK();	/* ä */
+  OCHU_THREADS_LEAVE();
+#else
   gdk_threads_leave();
+#endif
 
   terminate_workers();
   xmlCleanupParser();
 
 #if TRACE_MEMORY_USAGE
-  g_object_unref(G_OBJECT(application->table));
+  OCHU_OBJECT_UNREF(G_OBJECT(application->table));
   application->table = NULL;
-  g_object_unref(G_OBJECT(application->broker));
+  OCHU_OBJECT_UNREF(G_OBJECT(application->broker));
   application->broker = NULL;
 
   G_FREE(application->threadlist_view_contents);
