@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.55 2003/12/24 03:41:41 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.57 2003/12/29 05:21:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -885,7 +885,9 @@ setup_tab_label_icons(void)
 static void
 delete_event_cb(GtkWidget *widget, GdkEventAny *event, gpointer user_data)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
   on_quit(user_data, 0, widget);
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -893,36 +895,44 @@ delete_event_cb(GtkWidget *widget, GdkEventAny *event, gpointer user_data)
 static void
 go_forward_button_cb(gpointer unused, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
 #if DEBUG_GUI
   fprintf(stderr, "go_forward_button_cb: not implemented.\n");
 #endif
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 go_back_button_cb(gpointer unused, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
 #if DEBUG_GUI
   fprintf(stderr, "go_forward_button_cb: not implemented.\n");
 #endif
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 refresh_button_cb(gpointer unused, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
 #if DEBUG_GUI
   fprintf(stderr, "refresh_button_cb: not implemented.\n");
 #endif
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 cancel_button_cb(gpointer unused, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
 #if DEBUG_GUI
   fprintf(stderr, "cancel_button_cb: not implemented.\n");
 #endif
+  ENTER_MAIN_EVENT_LOOP();
 }
 #endif
 
@@ -958,14 +968,19 @@ static void
 main_menu_callback(gpointer data, guint action, GtkWidget *widget)
 {
   OchushaApplication *application = (OchushaApplication *)data;
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   switch (action)
     {
     case MAIN_MENU_OPEN_URL:
       popup_open_url_dialog(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
     case MAIN_MENU_REFRESH_BOARDLIST:
       refresh_boardlist(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
     case MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS:
@@ -985,44 +1000,52 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
 	else
 	  application->hide_hidden_threads
 	    = gtk_check_menu_item_get_active(item);
-
+	ENTER_MAIN_EVENT_LOOP();
 	return;
       }
 
     case MAIN_MENU_REFRESH_THREAD:
       refresh_current_thread(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
 #if 0
     case MAIN_MENU_REFRESH_THREAD_ALL:
       refresh_current_thread_all(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 #endif
 
     case MAIN_MENU_REFRESH_THREADLIST:
       refresh_current_threadlist(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
     case MAIN_MENU_REFRESH_THREADLIST_ALL:
       refresh_current_threadlist_all(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
 #if ENABLE_DEBUG_CONSOLE
     case MAIN_MENU_DEBUG_CONSOLE:
       open_debug_console(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 #endif
 
     case MAIN_MENU_OPTIONS:
       open_preference_dialog(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
 
     case MAIN_MENU_ABOUT:
       open_about_dialog(application);
+      ENTER_MAIN_EVENT_LOOP();
       return;
     }
 
   fprintf(stderr, "Not implemented yet.\n");
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1039,17 +1062,18 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
 	  "    </attribute>\n", (config)->attribute ? "true" : "false" )
 
 #define OUTPUT_CONFIG_ATTRIBUTE_STRING(gzfile, config, attribute)	\
-  do {									\
-    if ((config)->attribute != NULL)					\
-      {									\
-	gchar *text = g_markup_escape_text((config)->attribute, -1);	\
-	gzprintf(gzfile,						\
-		"    <attribute name=\"" #attribute	"\">\n"		\
-		"      <string>%s</string>\n"				\
-		"    </attribute>\n", text);				\
-	g_free(text);							\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      if ((config)->attribute != NULL)					\
+	{								\
+	  gchar *text = g_markup_escape_text((config)->attribute, -1);	\
+	  gzprintf(gzfile,						\
+		   "    <attribute name=\"" #attribute	"\">\n"		\
+		   "      <string>%s</string>\n"			\
+		   "    </attribute>\n", text);				\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 static void
@@ -1401,7 +1425,8 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
 						     "bookmark_text");
   if (bookmark_text != NULL)
     {
-      application->bookmark_text = ochusha_utils_url_decode_string(bookmark_text);
+      application->bookmark_text
+	= ochusha_utils_url_decode_string(bookmark_text);
       G_FREE(bookmark_text);
     }
 
@@ -1413,7 +1438,8 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
     }
 
   if (application->bookmark_text == NULL)
-    application->bookmark_text = G_STRDUP(_("==== My bookmark: I have read above. ===="));
+    application->bookmark_text
+      = G_STRDUP(_("==== My bookmark: I have read above. ===="));
 
   application->show_mailto_mode
     = (ThreadViewMailtoMode)ochusha_utils_get_attribute_int(pref_attrs,
@@ -1543,9 +1569,11 @@ access_started_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
   counter = g_object_get_qdata(G_OBJECT(tab_label), tab_label_icon_counter_id);
   *counter = 0;
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   icon_label_set_icon(tab_label, tab_label_icons[TAB_LABEL_ICON_PREPARATION]);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -1580,10 +1608,12 @@ access_progressed_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
   counter = g_object_get_qdata(G_OBJECT(tab_label), tab_label_icon_counter_id);
   *counter = (*counter + 1) % 7;
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   icon_label_set_icon(tab_label,
 		      tab_label_icons[progress_icon_number[*counter]]);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -1602,9 +1632,11 @@ access_completed_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
   if (tab_label == NULL)
     return TRUE;
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   icon_label_set_icon(tab_label, tab_label_icons[TAB_LABEL_ICON_DONE]);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -1623,9 +1655,11 @@ access_terminated_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
   if (tab_label == NULL)
     return TRUE;
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   icon_label_set_icon(tab_label, tab_label_icons[TAB_LABEL_ICON_DONE]);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -1653,9 +1687,11 @@ access_failed_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
   if (tab_label == NULL)
     return TRUE;
 
-  gdk_threads_enter();
+  OCHU_THREADS_ENTER();
+
   icon_label_set_icon(tab_label, tab_label_icons[TAB_LABEL_ICON_ERROR]);
-  gdk_threads_leave();
+
+  OCHU_THREADS_LEAVE();
 
   return TRUE;
 }
@@ -1680,6 +1716,8 @@ static void
 preference_dialog_response_cb(GtkWidget *widget, gint response_id,
 			      OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   switch (response_id)
     {
     case GTK_RESPONSE_APPLY:
@@ -2026,9 +2064,13 @@ preference_dialog_response_cb(GtkWidget *widget, gint response_id,
     }
 
   if (response_id == GTK_RESPONSE_APPLY)
-    return;
+    {
+      ENTER_MAIN_EVENT_LOOP();
+      return;
+    }
 
   gtk_widget_destroy(widget);
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2238,12 +2280,15 @@ static void
 restore_default_cb(ThreadlistFilterSetting *setting,
 		   OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   threadlist_filter_setting_set_filter(setting,
 				       &application->user_default_filter);
 
   setting->filter.ignore_threshold
     = application->user_default_filter.ignore_threshold;
 
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2525,10 +2570,13 @@ static void
 debug_console_response_cb(GtkWidget *widget, gint response_id,
 			  gpointer unused)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (widget == NULL)
     return;
 
   gtk_widget_hide(widget);
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2538,6 +2586,7 @@ open_debug_console(OchushaApplication *application)
   GtkWidget *dialog;
   GtkWidget *scroll;
   GtkWidget *text_view;
+
   if (debug_console != NULL)
     {
       gtk_widget_show_all(debug_console);
@@ -2700,10 +2749,14 @@ open_about_dialog(OchushaApplication *application)
 static void
 about_dialog_response_cb(GtkWidget *widget, gint response_id, gpointer unused)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (widget == NULL)
     return;
 
   gtk_widget_destroy(widget);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2748,7 +2801,11 @@ initialize_open_url_dialog(OchushaApplication *application)
 static void
 open_url_combo_entry_activate_cb(GtkWidget *entry, GtkDialog *dialog)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_dialog_response(dialog, GTK_RESPONSE_OK);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2756,6 +2813,8 @@ static void
 open_url_dialog_response_cb(GtkWidget *dialog, gint response_id,
 			    OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (response_id == GTK_RESPONSE_OK)
     {
       const gchar *url
@@ -2772,6 +2831,7 @@ open_url_dialog_response_cb(GtkWidget *dialog, gint response_id,
       open_url_dialog = NULL;
     }
 #endif
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
