@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.43 2003/12/24 05:17:03 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.44.2.1 2003/12/29 09:04:38 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -36,20 +36,15 @@
 #include "ochusha_bbs_table.h"
 #include "ochusha_network_broker.h"
 
+#include "ochusha_ui_private.h"
+
 #include "icon_label.h"
 
 #include <glib.h>
 #include <gtk/gtk.h>
 
 
-#define DEBUG_GUI		0
-#define DEBUG_GUI_MOST		0
-#define DEBUG_THREAD		0
-#define DEBUG_THREAD_MOST	0
-#define DEBUG_WIDGET		0
-#define DEBUG_WIDGET_MOST	0
-
-#define ENABLE_DEBUG_CONSOLE						0
+#define ENABLE_DEBUG_CONSOLE						1
 #define ENABLE_MAIN_TOOLBAR						0
 
 #define OCHUSHA_SESSION_XML				"session.xml.gz"
