@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.9 2003/12/21 02:23:13 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.10.2.1 2003/12/29 09:04:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -41,8 +41,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#define ENABLE_ARROW_BUTTONS	1
-
 
 static void paned_notebook_class_init(PanedNotebookClass *klass);
 static void paned_notebook_set_property(GObject *object, guint prop_id,
@@ -443,7 +441,7 @@ paned_notebook_init(PanedNotebook *paned_notebook)
   paned_notebook->tab_policy = GTK_POLICY_AUTOMATIC;
   paned_notebook->always_show_contents_pane = FALSE;
 
-  g_object_ref(G_OBJECT(paned_notebook->contents_pane));
+  OCHU_OBJECT_REF(G_OBJECT(paned_notebook->contents_pane));
   g_signal_connect(G_OBJECT(paned_notebook->contents_pane),
 		   "destroy",
 		   G_CALLBACK(gtk_widget_destroyed),
@@ -515,7 +513,7 @@ paned_notebook_destroy(GtkObject *object)
 
   if (paned_notebook->contents_pane != NULL)
     {
-      g_object_unref(G_OBJECT(paned_notebook->contents_pane));
+      OCHU_OBJECT_UNREF(G_OBJECT(paned_notebook->contents_pane));
       paned_notebook->contents_pane = NULL;
     }
 
@@ -1290,7 +1288,7 @@ close_nth_page(PanedNotebook *paned_notebook, gint page)
       paned_notebook->current_item_view = NULL;
     }
 
-  g_object_ref(G_OBJECT(widget));
+  OCHU_OBJECT_REF(G_OBJECT(widget));
 
   g_signal_emit(G_OBJECT(paned_notebook),
 		paned_notebook_signals[ITEM_VIEW_BEING_CLOSED_SIGNAL],
@@ -1326,7 +1324,7 @@ close_nth_page(PanedNotebook *paned_notebook, gint page)
 		item,
 		widget);
 
-  g_object_unref(G_OBJECT(widget));
+  OCHU_OBJECT_UNREF(G_OBJECT(widget));
 
   gtk_container_remove(GTK_CONTAINER(paned_notebook->contents_list),
 		       menu_item);
@@ -1372,6 +1370,8 @@ button_press_event_cb(ModNotebook *notebook, GdkEventButton *event,
 {
   g_return_val_if_fail(notebook == paned_notebook->item_contents, FALSE);
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (event->button == 2)
     {
       gint page = mod_notebook_get_mouse_event_page_num(notebook,
@@ -1383,6 +1383,8 @@ button_press_event_cb(ModNotebook *notebook, GdkEventButton *event,
 	}
     }
 
+  ENTER_MAIN_EVENT_LOOP();
+
   return FALSE;
 }
 
@@ -1434,21 +1436,31 @@ menu_item_activate_cb(GtkMenuItem *menu_item, PanedNotebook *paned_notebook)
 static void
 close_item_view_button_cb(gpointer unused, PanedNotebook *paned_notebook)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   paned_notebook_close_current_item_view(paned_notebook);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
-#if ENABLE_ARROW_BUTTONS
 static void
 go_forward_button_cb(gpointer unused, PanedNotebook *paned_notebook)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   mod_notebook_next_page(paned_notebook->item_contents);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 go_back_button_cb(gpointer unused, PanedNotebook *paned_notebook)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   mod_notebook_prev_page(paned_notebook->item_contents);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
-#endif
