@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.c,v 1.34 2003/12/21 02:22:06 fuyu Exp $
+ * $Id: threadlist_view.c,v 1.36 2003/12/29 05:21:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -900,6 +900,8 @@ threadlist_view_move_cursor(GtkTreeView *tree_view, GtkMovementStep step,
   ThreadlistView *view = THREADLIST_VIEW(tree_view);
   gboolean result = FALSE;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   /*
    * use_native_searchǤʤ硢ġʤ饫ưѤ
    * ʥФ
@@ -917,9 +919,11 @@ threadlist_view_move_cursor(GtkTreeView *tree_view, GtkMovementStep step,
 		     ? THREADLIST_SEARCH_ACTION_FORWARD
 		     : THREADLIST_SEARCH_ACTION_BACKWARD),
 		    &result);
+      ENTER_MAIN_EVENT_LOOP();
       return TRUE;
     }
 
+  ENTER_MAIN_EVENT_LOOP();
   return (*parent_class->move_cursor)(&view->view, step, count);
 }
 
@@ -1145,10 +1149,13 @@ threadlist_view_interactive_search(ThreadlistView *view,
 {
   gboolean result;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (view->use_native_search)
     {
       gtk_widget_grab_focus(GTK_WIDGET(view));
 
+      ENTER_MAIN_EVENT_LOOP();
       return (*parent_class->start_interactive_search)(&view->view);
     }
   else
@@ -1161,6 +1168,7 @@ threadlist_view_interactive_search(ThreadlistView *view,
 		    &result);
     }
 
+  ENTER_MAIN_EVENT_LOOP();
   return result;
 }
 
@@ -1273,7 +1281,6 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 		    thread);
       break;
     }
-
 }
 
 
@@ -1281,9 +1288,13 @@ static void
 threadlist_view_do_on_selection(ThreadlistView *view, int what_to_do)
 {
   DoOnSelectionArgs args = { view, what_to_do };
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_tree_selection_selected_foreach(view->selection,
 			(GtkTreeSelectionForeachFunc)do_on_selection_helper,
 			&args);
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1301,6 +1312,8 @@ threadlist_view_do_on_thread_at_cursor(ThreadlistView *view, int what_to_do)
   if (!gtk_tree_model_get_iter(view->model, &iter, path))
     goto done;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_tree_model_get(view->model, &iter, THREADLIST_DATA, &data, -1);
 
   if (data != NULL)
@@ -1358,6 +1371,7 @@ threadlist_view_do_on_thread_at_cursor(ThreadlistView *view, int what_to_do)
 	  break;
 	}
     }
+  ENTER_MAIN_EVENT_LOOP();
 
  done:
   gtk_tree_path_free(path);
@@ -1372,7 +1386,14 @@ popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
   fprintf(stderr, "popup_menu_callback: view=%p, action=%d\n",
 	  view, action);
 #endif
+  /* MAIN_THREAD_EVENT_CALLBACK(); */
+  /*
+   * threadlist_view_do_on_selection()ϥ٥ȤľܤƤФΤǡ
+   * äб
+   */
   threadlist_view_do_on_selection(view, action);
+
+  /* ENTER_MAIN_EVENT_LOOP(); */
 }
 
 
@@ -1426,6 +1447,8 @@ tree_view_motion_notify_event_cb(GtkWidget *widget, GdkEventMotion *event,
   if (!gtk_tree_model_get_iter(view->model, &iter, path))
     goto done;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_tree_model_get(view->model, &iter, THREADLIST_DATA, &data, -1);
 
   if (view->recently_pointed_thread != data)
@@ -1447,6 +1470,8 @@ tree_view_motion_notify_event_cb(GtkWidget *widget, GdkEventMotion *event,
 		      thread);
     }
 
+  ENTER_MAIN_EVENT_LOOP();
+
  done:
   if (path != NULL)
     gtk_tree_path_free(path);
@@ -1459,6 +1484,8 @@ static gboolean
 tree_view_leave_notify_event_cb(GtkWidget *widget, GdkEventCrossing *event,
 				ThreadlistView *view)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (view->recently_pointed_thread != NULL)
     {
       g_signal_emit(G_OBJECT(view),
@@ -1469,6 +1496,7 @@ tree_view_leave_notify_event_cb(GtkWidget *widget, GdkEventCrossing *event,
       view->recently_pointed_thread = NULL;
     }
 
+  ENTER_MAIN_EVENT_LOOP();
   return FALSE;
 }
 
@@ -1490,6 +1518,8 @@ tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
   if (!gtk_tree_model_get_iter(view->model, &iter, path))
     goto done;
 
+  MAIN_THREAD_EVENT_CALLBACK();
+
   gtk_tree_model_get(view->model, &iter, THREADLIST_DATA, &data, -1);
 
   if (data != NULL)
@@ -1525,6 +1555,7 @@ tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
 	    }
 	}
     }
+  ENTER_MAIN_EVENT_LOOP();
 
  done:
   if (path != NULL)
@@ -1538,6 +1569,10 @@ static gboolean
 tree_view_button_release_event_cb(GtkWidget *widget, GdkEventButton *event,
 				  ThreadlistView *view)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
+  ENTER_MAIN_EVENT_LOOP();
+
   return FALSE;
 }
 
@@ -2142,6 +2177,7 @@ threadlist_view_append_rank(ThreadlistView *view)
   column = gtk_tree_view_column_new_with_attributes(_("Rank"), renderer,
 						    "text", THREADLIST_RANK,
 						    NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  text_set_cell_data_rank,
 					  view, NULL);
@@ -2166,6 +2202,7 @@ threadlist_view_append_mark(ThreadlistView *view)
   column = gtk_tree_view_column_new_with_attributes(_("Mark"), renderer,
 					"active", THREADLIST_VISUAL_PARAMETER,
 					NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  active_set_cell_data_flags,
 					  view, NULL);
@@ -2188,6 +2225,7 @@ threadlist_view_append_title(ThreadlistView *view)
   column = gtk_tree_view_column_new_with_attributes(_("Thread Title"),
 						    renderer, "text",
 						    THREADLIST_TITLE, NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  decorate_threadlist_entry,
 					  view, NULL);
@@ -2215,6 +2253,7 @@ threadlist_view_append_number_of_responses(ThreadlistView *view)
 						    renderer, "text",
 						    THREADLIST_N_RESPONSES,
 						    NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  decorate_threadlist_entry,
 					  view, NULL);
@@ -2242,6 +2281,7 @@ threadlist_view_append_number_of_responses_got(ThreadlistView *view)
 						renderer, "text",
 						THREADLIST_N_RESPONSES_GOT,
 						NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  decorate_threadlist_entry,
 					  view, NULL);
@@ -2269,6 +2309,7 @@ threadlist_view_append_number_of_responses_ungot(ThreadlistView *view)
 						renderer, "text",
 						THREADLIST_N_RESPONSES_UNGOT,
 						NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  decorate_threadlist_entry,
 					  view, NULL);
@@ -2296,6 +2337,7 @@ threadlist_view_append_number_of_responses_shown(ThreadlistView *view)
 						renderer, "text",
 						THREADLIST_N_RESPONSES_SHOWN,
 						NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  decorate_threadlist_entry,
 					  view, NULL);
@@ -2323,6 +2365,7 @@ threadlist_view_append_number_of_responses_unread(ThreadlistView *view)
 						renderer, "text",
 						THREADLIST_N_RESPONSES_UNREAD,
 						NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  decorate_threadlist_entry,
 					  view, NULL);
@@ -2351,6 +2394,7 @@ threadlist_view_append_number_of_responses_verbose(ThreadlistView *view)
 						    renderer, "text",
 						    THREADLIST_N_RESPONSES,
 						    NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  text_set_num_of_responses_verbose,
 					  view, NULL);
@@ -2374,6 +2418,7 @@ threadlist_view_append_rank_difference(ThreadlistView *view)
 						    renderer, "text",
 						    THREADLIST_RANK_DIFFERENCE,
 						    NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  text_set_cell_data_rank_diff,
 					  view, NULL);
@@ -2398,6 +2443,7 @@ threadlist_view_append_last_modified(ThreadlistView *view)
 						    renderer, "text",
 						    THREADLIST_LAST_MODIFIED,
 						    NULL);
+  gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_cell_data_func(column, renderer,
 					  text_set_cell_data_last_modified,
 					  view, NULL);
@@ -2503,6 +2549,8 @@ threadlist_view_append_thread(ThreadlistView *view, OchushaBBSThread *thread,
     rank = RANK_DAT_DROPPED;
   else
     rank = new_rank;
+
+  CHECK_THREADS_ENTERED();
   set_thread_values(view, GTK_LIST_STORE(view->model),
 		    num_shown, num_unread, last_rank, rank, thread);
 }
@@ -2534,6 +2582,7 @@ threadlist_view_update_thread(ThreadlistView *view, OchushaBBSThread *thread,
 #endif
   g_return_if_fail(thread == data);
 
+  CHECK_THREADS_ENTERED();
   set_thread_values(view, GTK_LIST_STORE(view->model),
 		    num_shown, num_unread, 0, RANK_UNSPECIFIED, thread);
 }
