@@ -23,9 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ugly_gtk2utils.c,v 1.8 2003/11/07 14:27:06 fuyu Exp $
+ * $Id: ugly_gtk2utils.c,v 1.9.2.1 2003/12/29 09:04:38 fuyu Exp $
  */
 
+#include "config.h"
+
+#include "ochusha_private.h"
+#include "ochusha_ui.h"
+
 #include "ugly_gtk2utils.h"
 
 #include <glib.h>
@@ -37,15 +42,48 @@
 static gboolean
 delayed_g_object_unref_real(gpointer data)
 {
+#if DEBUG_REF_COUNT
+  GtkWidget *child;
+#endif
   g_return_val_if_fail(G_IS_OBJECT(data), FALSE);
 #if DEBUG_GUI
   fprintf(stderr, "delayed_g_object_unref_real: data=%p data->ref_count=%d\n",
 	  data, G_OBJECT(data)->ref_count);
 #endif
   if (G_OBJECT(data)->ref_count > 1)
-    return TRUE;
+    {
+#if DEBUG_REF_COUNT
+      fprintf(stderr, "delayed_g_object_unref_real: data=%p is still alive\n",
+	      data);
+#endif
+      return TRUE;
+    }
+
+#if DEBUG_REF_COUNT
+  if (GTK_IS_BIN(data))
+    {
+      child = gtk_bin_get_child(GTK_BIN(data));
+      fprintf(stderr, "delayed_g_object_unref_real: child(%p)->ref_count=%d\n",
+	      child, G_OBJECT(child)->ref_count);
+    }
+  else
+    child = NULL;
+#endif
+
+  OCHU_THREADS_ENTER();
+
+  OCHU_OBJECT_UNREF(G_OBJECT(data));
+
+  OCHU_THREADS_LEAVE();
+
+#if DEBUG_REF_COUNT
+  if (child != NULL)
+    {
+      fprintf(stderr, "delayed_g_object_unref_real: child(%p)->ref_count=%d\n",
+	      child, ((GObject *)child)->ref_count);
+    }
+#endif
 
-  g_object_unref(G_OBJECT(data));
 #if DEBUG_GUI
   fprintf(stderr, "delayed_g_object_unref_real:  data=%p data->ref_count=%d\n",
 	  data, ((GObject *)data)->ref_count);
