@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.8 2003/12/16 17:25:59 fuyu Exp $
+ * $Id: ochusha.h,v 1.11 2003/12/24 05:16:32 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -34,15 +34,15 @@
 #include <glib.h>
 #include <iconv.h>
 
-#include <stdio.h>
+#include <zlib.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#define OCHUSHA_BOARDLIST_XML		"boardlist.xml"
-#define OCHUSHA_CONFIG_XML		"config.xml"
-#define OCHUSHA_THREADLIST_XML		"threadlist.xml"
+#define OCHUSHA_BOARDLIST_XML		"boardlist.xml.gz"
+#define OCHUSHA_CONFIG_XML		"config.xml.gz"
+#define OCHUSHA_THREADLIST_XML		"threadlist.xml.gz"
 
 #define OCHUSHA_USER_AGENT		"Monazilla/1.00 (Ochusha/" VERSION ")"
 
@@ -99,11 +99,15 @@ struct _OchushaConfig
  */
 void ochusha_config_prepare_home(OchushaConfig *config);
 char *ochusha_config_find_file(const OchushaConfig *config,
-			       const char *filename);
+			       const char *filename, const char *dir);
 char *ochusha_config_find_directory(const OchushaConfig *config,
-				    const char *filename);
+				    const char *filename, const char *dir);
 int ochusha_config_open_file(const OchushaConfig *config, const char *filename,
-			     int flags);
+			     const char *dir, int flags);
+void ochusha_config_unlink_file(const OchushaConfig *config,
+				const char *filename, const char *dir);
+void ochusha_config_unlink_directory(const OchushaConfig *config,
+				     const char *dirname);
 
 gboolean ochusha_config_cache_file_exist(const OchushaConfig *config,
 					 const char *url);
@@ -116,14 +120,15 @@ void ochusha_config_cache_unlink_file(const OchushaConfig *config,
 /*
  * config.xmlϢ
  */
-typedef void WritePreferenceElementFunc(FILE *config_xml, gpointer user_data);
+typedef void WritePreferenceElementFunc(gzFile *config_xml,
+					gpointer user_data);
 typedef void ReadPreferenceElementFunc(GHashTable *pref_attrs,
 				       gpointer user_data);
 
-gboolean ochusha_write_config_xml(OchushaConfig *config,
+gboolean ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
 				  WritePreferenceElementFunc *optional,
 				  gpointer user_data);
-void ochusha_read_config_xml(OchushaConfig *config,
+void ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
 			     ReadPreferenceElementFunc *optional,
 			     gpointer user_data);
 
