@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.c,v 1.12 2003/12/19 03:11:47 fuyu Exp $
+ * $Id: ochusha_async_buffer.c,v 1.14.2.2 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -33,6 +33,8 @@
 #include "ochusha_async_buffer.h"
 #include "marshal.h"
 
+#include "worker.h"
+
 #include <glib.h>
 
 #include <errno.h>
@@ -47,6 +49,12 @@
 #include <sys/types.h>
 #include <sys/mman.h>
 
+#ifdef HAVE_NANOSLEEP
+#include <time.h>
+#else
+#include <unistd.h>
+#endif
+
 #include <zlib.h>
 
 
@@ -149,31 +157,32 @@ static GSList *ochusha_async_buffer_list = NULL;
     }
 
 #define LOCK_BUFFER_LOCK(buffer)					\
-  do {									\
-    int result = pthread_mutex_trylock(&buffer->sync_object->mutex);	\
-    if (result != 0)							\
-      {									\
-	if (result == EBUSY)						\
-	  {								\
-            LOCK_GLOBAL_LOCK;						\
-	    buffer->number_of_lock_waiters++;				\
-            UNLOCK_GLOBAL_LOCK;						\
-	    if (pthread_mutex_lock(&buffer->sync_object->mutex) != 0)	\
-	      {								\
-		fprintf(stderr, "Couldn't lock a mutex.\n");		\
-		abort();						\
-	      }								\
-            LOCK_GLOBAL_LOCK;						\
-	    buffer->number_of_lock_waiters--;				\
-            UNLOCK_GLOBAL_LOCK;						\
-	  }								\
-	else								\
-	  {								\
-	    fprintf(stderr, "Couldn't trylock a mutex.\n");		\
-	    abort();							\
-	  }								\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      int result = pthread_mutex_trylock(&buffer->sync_object->mutex);	\
+      if (result != 0)							\
+	{								\
+	  if (result == EBUSY)						\
+	    {								\
+	      LOCK_GLOBAL_LOCK;						\
+	      buffer->number_of_lock_waiters++;				\
+	      UNLOCK_GLOBAL_LOCK;					\
+	      if (pthread_mutex_lock(&buffer->sync_object->mutex) != 0)	\
+		{							\
+		  fprintf(stderr, "Couldn't lock a mutex.\n");		\
+		  abort();						\
+		}							\
+	      LOCK_GLOBAL_LOCK;						\
+	      buffer->number_of_lock_waiters--;				\
+	      UNLOCK_GLOBAL_LOCK;					\
+	    }								\
+	  else								\
+	    {								\
+	      fprintf(stderr, "Couldn't trylock a mutex.\n");		\
+	      abort();							\
+	    }								\
+	}								\
+    } while (0)
 #if 0
 #define LOCK_BUFFER_LOCK(buffer)				\
   if (pthread_mutex_lock(&buffer->sync_object->mutex) != 0)	\
@@ -222,10 +231,71 @@ enum {
 static gint async_buffer_signals[LAST_SIGNAL] = { 0, };
 
 
+void
+blind_awake(OchushaAsyncBuffer *buffer)
+{
+  LOCK_BUFFER_LOCK(buffer);
+
+  if (buffer->state == OCHUSHA_ASYNC_BUFFER_OK
+      && buffer->number_of_active_users > 0)
+    {
+#if 0
+      fprintf(stderr, "blind awake on %p\n", buffer);
+#endif
+      BROADCAST_BUFFER_CONDITION(buffer);
+    }
+
+  UNLOCK_BUFFER_LOCK(buffer);
+
+  g_object_unref(G_OBJECT(buffer));	/* ڥˤʤäƤϤ */
+}
+
+
+static GSList *to_be_signaled_buffer_list = NULL;
+
+
+static void
+iterate_buffers_to_be_signaled(OchushaAsyncBuffer *buffer)
+{
+  g_object_ref(G_OBJECT(buffer));	/* ڥˤʤäƤϤ */
+  to_be_signaled_buffer_list = g_slist_append(to_be_signaled_buffer_list,
+					      buffer);
+}
+
+
+static void
+force_awake_job(WorkerThread *employee, void *unused)
+{
+#ifdef HAVE_NANOSLEEP
+  struct timespec interval = { 0, 100000000 };	/* == 100ms */
+#endif
+
+  while (TRUE)
+    {
+      LOCK_GLOBAL_LOCK;
+      to_be_signaled_buffer_list = NULL;
+      g_slist_foreach(ochusha_async_buffer_list,
+		      (GFunc)iterate_buffers_to_be_signaled, NULL);
+      UNLOCK_GLOBAL_LOCK;
+
+      g_slist_foreach(to_be_signaled_buffer_list, (GFunc)blind_awake, NULL);
+
+      if (employee->command == DIE_NOW)
+	break;
+#ifdef HAVE_NANOSLEEP
+      nanosleep(&interval, NULL);
+#else
+      sleep(1);		/* Ĺʤ뤬ʤ */
+#endif
+    }
+}
+
+
 static void
 ochusha_async_buffer_class_init(OchushaAsyncBufferClass *klass)
 {
   GObjectClass *o_class = (GObjectClass *)klass;
+  WorkerJob *job = G_NEW0(WorkerJob, 1);
 
   if (pthread_mutex_init(&ochusha_async_buffer_global_lock, NULL) != 0)
     {
@@ -251,6 +321,12 @@ ochusha_async_buffer_class_init(OchushaAsyncBufferClass *klass)
 		 G_TYPE_NONE, 0);
 
   o_class->finalize = ochusha_async_buffer_finalize;
+
+  job->canceled = FALSE;
+  job->job = force_awake_job;
+  job->args = NULL;
+
+  commit_job(job);
 }
 
 
@@ -516,7 +592,7 @@ ochusha_async_buffer_active_ref(OchushaAsyncBuffer *buffer)
 #if DEBUG_OCHUSHA_ASYNC_BUFFER_MOST
   fprintf(stderr, "OchushaAsyncBuffer(%p) is actively refered\n", buffer);
 #endif
-  g_object_ref(G_OBJECT(buffer));
+  g_object_ref(G_OBJECT(buffer));	/* Ĵ٤Ƥʤ */
 
   LOCK_BUFFER_LOCK(buffer);
 
@@ -536,7 +612,7 @@ ochusha_async_buffer_active_ref(OchushaAsyncBuffer *buffer)
   if (!result)
     {
       buffer->number_of_active_users--;
-      g_object_unref(G_OBJECT(buffer));
+      g_object_unref(G_OBJECT(buffer));	/* Ĵ٤Ƥʤ */
     }
 
   UNLOCK_BUFFER_LOCK(buffer);
@@ -567,7 +643,7 @@ ochusha_async_buffer_active_unref(OchushaAsyncBuffer *buffer)
 
   UNLOCK_BUFFER_LOCK(buffer);
 
-  g_object_unref(G_OBJECT(buffer));
+  g_object_unref(G_OBJECT(buffer));	/* Ĵ٤Ƥʤ */
 }
 
 
