@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.18 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.18.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -163,13 +163,13 @@ ochusha_bbs_table_init(OchushaBBSTable *table)
 {
   table->category_table
     = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
-			    (GDestroyNotify)g_object_unref);
+			    (GDestroyNotify)OCHU_OBJECT_UNREF_FUNC);
   table->board_table
     = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
-			    (GDestroyNotify)g_object_unref);
+			    (GDestroyNotify)OCHU_OBJECT_UNREF_FUNC);
   table->board_name_table
     = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
-			    (GDestroyNotify)g_object_unref);
+			    (GDestroyNotify)OCHU_OBJECT_UNREF_FUNC);
 }
 
 
@@ -227,7 +227,7 @@ ochusha_bbs_table_add_category(OchushaBBSTable *table,
   if (g_hash_table_lookup(table->category_table, category->name) != NULL)
     return;	/* ϿѤξ */
 
-  g_object_ref(G_OBJECT(category));
+  OCHU_OBJECT_REF(G_OBJECT(category));
   g_hash_table_insert(table->category_table, category->name, category);
 
   table->category_list = g_slist_append(table->category_list, category);
@@ -262,10 +262,10 @@ ochusha_bbs_table_add_board(OchushaBBSTable *table,
   g_return_if_fail(OCHUSHA_IS_BBS_TABLE(table)
 		   && OCHUSHA_IS_BULLETIN_BOARD(board));
 
-  g_object_ref(G_OBJECT(board));
+  OCHU_OBJECT_REF(G_OBJECT(board));
   g_hash_table_insert(table->board_table, board->base_url, board);
 
-  g_object_ref(G_OBJECT(board));
+  OCHU_OBJECT_REF(G_OBJECT(board));
   g_hash_table_insert(table->board_name_table, board->name, board);
 
   return;
@@ -281,7 +281,7 @@ ochusha_bbs_table_remove_board(OchushaBBSTable *table,
   g_return_if_fail(OCHUSHA_IS_BBS_TABLE(table)
 		   && OCHUSHA_IS_BULLETIN_BOARD(board));
 
-  g_object_ref(G_OBJECT(board));
+  OCHU_OBJECT_REF(G_OBJECT(board));
 
   entry = g_hash_table_lookup(table->board_table, board->base_url);
   if (entry == board)
@@ -406,7 +406,7 @@ typedef struct _SAXContext
 static void
 board_list_free(GSList *board_list)
 {
-  g_slist_foreach(board_list, (GFunc)g_object_unref, NULL);
+  g_slist_foreach(board_list, (GFunc)OCHU_OBJECT_UNREF_FUNC, NULL);
   g_slist_free(board_list);
 }
 
@@ -756,7 +756,7 @@ endElementHandler(void *context, const xmlChar *name)
 	      if (category == NULL)
 		category = ochusha_board_category_new(category_name);
 	      else
-		g_object_ref(G_OBJECT(category));
+		OCHU_OBJECT_REF(G_OBJECT(category));
 
 #if DEBUG_LIBOCHUSHA_MORE
 	      fprintf(stderr, "emitting read_boardlist_element for category.\n");
@@ -777,7 +777,7 @@ endElementHandler(void *context, const xmlChar *name)
 						   sax_context->board_list);
 	      sax_context->board_list = NULL;
 	      ochusha_bbs_table_add_category(table, category);
-	      g_object_unref(G_OBJECT(category));
+	      OCHU_OBJECT_UNREF(G_OBJECT(category));
 #if DEBUG_SAX_HANDLER
 	      fprintf(stderr, "adding category: %s\n", category_name);
 #endif
@@ -856,7 +856,7 @@ endElementHandler(void *context, const xmlChar *name)
 				sax_context->board_attributes);
 
 		  ochusha_bbs_table_add_board(table, board);
-		  g_object_unref(G_OBJECT(board));
+		  OCHU_OBJECT_UNREF(G_OBJECT(board));
 		}
 	    }
 
