@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.19 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.19.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -203,7 +203,7 @@ ochusha_bbs_thread_finalize(GObject *object)
   if (thread->board != NULL)
     {
 #if 0	/* Ȥ롼פΤǱѤǥС */
-      g_object_unref(thread->board);
+      OCHU_OBJECT_UNREF(thread->board);
 #endif
       thread->board = NULL;
     }
@@ -303,10 +303,10 @@ ochusha_bbs_thread_set_board(OchushaBBSThread *thread,
 
 #if 0	/* Ȥ롼פƤޤΤǱѤǥС */
   if (thread->board != NULL)
-    g_object_unref(G_OBJECT(thread->board));
+    OCHU_OBJECT_UNREF(G_OBJECT(thread->board));
 
   if (board != NULL)
-    g_object_ref(G_OBJECT(board));
+    OCHU_OBJECT_REF(G_OBJECT(board));
 #endif
 
   thread->board = board;
