@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.26 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.27.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -241,17 +241,18 @@ ochusha_board_2ch_read_boardlist_element(OchushaBulletinBoard *board,
 
 
 #define OUTPUT_BOARD_ATTRIBUTE_STRING(gzfile, board, attribute)		\
-  do {									\
-    if ((board)->attribute != NULL)					\
-      {									\
-        gchar *text = g_markup_escape_text((board)->attribute, -1);	\
-        gzprintf(gzfile,						\
-	  "        <attribute name=\"" #attribute	"\">\n"		\
-	  "          <string>%s</string>\n"				\
-	  "        </attribute>\n", text);				\
-        g_free(text);							\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      if ((board)->attribute != NULL)					\
+	{								\
+	  gchar *text = g_markup_escape_text((board)->attribute, -1);	\
+	  gzprintf(gzfile,						\
+		   "        <attribute name=\"" #attribute	"\">\n"	\
+		   "          <string>%s</string>\n"			\
+		   "        </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 static void
@@ -375,7 +376,7 @@ ochusha_board_2ch_recover_threadlist(OchushaBulletinBoard *board,
 						     recover_title,
 						     NULL, NULL, NULL,
 						     NULL);
-		  g_object_unref(dat_buffer);
+		  OCHU_OBJECT_UNREF(G_OBJECT(dat_buffer));
 		  thread->number_of_responses_read = 1;
 		  board->thread_list = g_slist_append(board->thread_list,
 						      thread);
@@ -532,7 +533,7 @@ ochusha_board_2ch_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
 						 NULL, NULL, NULL, NULL);
 	      ochusha_async_buffer_suspend(dat_buffer);
 	      ochusha_async_buffer_terminate(dat_buffer);
-	      g_object_unref(dat_buffer);
+	      OCHU_OBJECT_UNREF(G_OBJECT(dat_buffer));
 
 	      if (thread->title != NULL)
 		{
@@ -542,7 +543,7 @@ ochusha_board_2ch_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
 		}
 	      else
 		{
-		  g_object_unref(thread);
+		  OCHU_OBJECT_UNREF(G_OBJECT(thread));
 		  thread = NULL;
 		}
 	    }
@@ -895,7 +896,7 @@ collect_dropped_thread(gpointer data, gpointer user_data)
 	  = g_slist_append(thread->board->dropped_list, thread);
     }
   else
-    g_object_unref(G_OBJECT(data));	/* Ƥ륹thread_list
+    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
 					 * Ѥ;פrefƤ롣
 					 */
 }
@@ -906,7 +907,7 @@ undo_thread_ref(gpointer data, gpointer user_data)
 {
   OchushaThread2ch *thread_2ch = OCHUSHA_THREAD_2CH(data);
   if (thread_2ch->alive)
-    g_object_unref(G_OBJECT(data));	/* Ƥ륹thread_list
+    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
 					 * Ѥ;פrefƤ롣
 					 */
 }
@@ -1060,7 +1061,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 		thread->flags &= ~OCHUSHA_BBS_THREAD_DAT_DROPPED;
 		thread->number_of_responses_on_server = n_responses_on_server;
 
-		g_object_ref(G_OBJECT(thread));
+		OCHU_OBJECT_REF(G_OBJECT(thread));
 		thread_list = g_slist_append(thread_list, thread);
 
 		if (each_thread_cb != NULL
