@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.c,v 1.7 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_board_category.c,v 1.8.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -179,7 +179,8 @@ ochusha_board_category_finalize(GObject *object)
 
   if (category->board_list != NULL)
     {
-      g_slist_foreach(category->board_list, (GFunc)g_object_unref, NULL);
+      g_slist_foreach(category->board_list,
+		      (GFunc)OCHU_OBJECT_UNREF_FUNC, NULL);
       g_slist_free(category->board_list);
       category->board_list = NULL;
     }
@@ -269,7 +270,7 @@ ochusha_board_category_add_board(OchushaBoardCategory *category,
 
   if (g_slist_find(category->board_list, board) == NULL)
     {
-      g_object_ref(G_OBJECT(board));
+      OCHU_OBJECT_REF(G_OBJECT(board));
       category->board_list = g_slist_append(category->board_list, board);
     }
 }
@@ -286,7 +287,7 @@ ochusha_board_category_remove_board(OchushaBoardCategory *category,
     return;
 
   category->board_list = g_slist_remove(category->board_list, board);
-  g_object_unref(G_OBJECT(board));
+  OCHU_OBJECT_UNREF(G_OBJECT(board));
 }
 
 
@@ -366,17 +367,18 @@ ochusha_board_category_lookup_board_by_name(OchushaBoardCategory *category,
     } while (0)
 
 #define OUTPUT_CATEGORY_ATTRIBUTE_STRING(gzfile, category, attribute)	\
-  do {									\
-    if ((category)->attribute)						\
-      {									\
-	gchar *text = g_markup_escape_text((category)->attribute, -1);	\
-	gzprintf(gzfile,						\
-		"      <attribute name=\"" #attribute	"\">\n"		\
-		"        <string>%s</string>\n"				\
-		"      </attribute>\n", text);				\
-	g_free(text);							\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      if ((category)->attribute)					\
+	{								\
+	  gchar *text = g_markup_escape_text((category)->attribute, -1); \
+	  gzprintf(gzfile,						\
+		   "      <attribute name=\"" #attribute	"\">\n"	\
+		   "        <string>%s</string>\n"			\
+		   "      </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 static void
 ochusha_board_category_read_boardlist_element(OchushaBoardCategory *category,
