@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.6 2003/12/19 03:13:49 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.6.4.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -660,7 +660,7 @@ collect_dropped_thread(gpointer data, gpointer user_data)
 	  = g_slist_append(thread->board->dropped_list, thread);
     }
   else
-    g_object_unref(G_OBJECT(data));	/* Ƥ륹thread_list
+    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
 					 * Ѥ;פrefƤ롣
 					 */
 }
@@ -671,7 +671,7 @@ undo_thread_ref(gpointer data, gpointer user_data)
 {
   OchushaThread2ch *thread_2ch = OCHUSHA_THREAD_2CH(data);
   if (thread_2ch->alive)
-    g_object_unref(G_OBJECT(data));	/* Ƥ륹thread_list
+    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
 					 * Ѥ;פrefƤ롣
 					 */
 }
@@ -826,7 +826,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 		thread->flags &= ~OCHUSHA_BBS_THREAD_DAT_DROPPED;
 		thread->number_of_responses_on_server = n_responses_on_server;
 
-		g_object_ref(G_OBJECT(thread));
+		OCHU_OBJECT_REF(G_OBJECT(thread));
 		thread_list = g_slist_append(thread_list, thread);
 
 		if (each_thread_cb != NULL
@@ -1048,7 +1048,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 		thread->flags &= ~OCHUSHA_BBS_THREAD_DAT_DROPPED;
 		thread->number_of_responses_on_server = n_responses_on_server;
 
-		g_object_ref(G_OBJECT(thread));
+		OCHU_OBJECT_REF(G_OBJECT(thread));
 		thread_list = g_slist_append(thread_list, thread);
 
 		if (each_thread_cb != NULL
