@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.21 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.21.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -219,8 +219,9 @@ ochusha_bulletin_board_init(OchushaBulletinBoard *board)
   board->id = NULL;
 
   board->thread_list = NULL;
-  board->thread_table = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
-					      (GDestroyNotify)g_object_unref);
+  board->thread_table
+    = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
+			    (GDestroyNotify)OCHU_OBJECT_UNREF_FUNC);
   board->dropped_list = NULL;
 
   board->bbs_type = OCHUSHA_BBS_TYPE_UNKNOWN;
@@ -264,7 +265,7 @@ ochusha_bulletin_board_finalize(GObject *object)
 
   if (board->thread_list != NULL)
     {
-      g_slist_foreach(board->thread_list, (GFunc)g_object_unref, NULL);
+      g_slist_foreach(board->thread_list, (GFunc)OCHU_OBJECT_UNREF_FUNC, NULL);
       g_slist_free(board->thread_list);
       board->thread_list = NULL;
     }
@@ -277,7 +278,8 @@ ochusha_bulletin_board_finalize(GObject *object)
 
   if (board->dropped_list != NULL)
     {
-      g_slist_foreach(board->dropped_list, (GFunc)g_object_unref, NULL);
+      g_slist_foreach(board->dropped_list,
+		      (GFunc)OCHU_OBJECT_UNREF_FUNC, NULL);
       g_slist_free(board->dropped_list);
       board->dropped_list = NULL;
     }
