@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.22 2003/12/24 06:21:32 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.23 2003/12/26 16:15:29 fuyu Exp $
  */
 
 #include "config.h"
@@ -915,17 +915,18 @@ getEntityHandler(void *context, const xmlChar *name)
 	  "    </attribute>\n", (config)->attribute ? "true" : "false" )
 
 #define OUTPUT_CONFIG_ATTRIBUTE_STRING(gzfile, config, attribute)	\
-  do {									\
-    if ((config)->attribute != NULL)					\
-      {									\
-	gchar *text = g_markup_escape_text((config)->attribute, -1);	\
-	gzprintf(gzfile,						\
-		"    <attribute name=\"" #attribute	"\">\n"		\
-		"      <string>%s</string>\n"				\
-		"    </attribute>\n", text);				\
-	g_free(text);							\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      if ((config)->attribute != NULL)					\
+	{								\
+	  gchar *text = g_markup_escape_text((config)->attribute, -1);	\
+	  gzprintf(gzfile,						\
+		   "    <attribute name=\"" #attribute	"\">\n"		\
+		   "      <string>%s</string>\n"			\
+		   "    </attribute>\n", text);				\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 gboolean
