@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.38 2003/12/19 03:12:13 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.38.4.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -623,7 +623,7 @@ timeout_cb(WorkerSyncObject *sync_object)
   if (!finished)
     return TRUE;
 
-  g_object_unref(G_OBJECT(sync_object));
+  OCHU_OBJECT_UNREF(G_OBJECT(sync_object));
 
   return FALSE;
 }
@@ -653,7 +653,7 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
 #if DEBUG_NETWORK_MOST
   fprintf(stderr, "leaving: poll_cb(%p)\n", sync_object);
 #endif
-  g_object_unref(G_OBJECT(sync_object));
+  OCHU_OBJECT_UNREF(G_OBJECT(sync_object));
 
   return FALSE;
 }
@@ -663,7 +663,7 @@ static void
 register_polling_function_for_read(WorkerSyncObject *sync_object, int fd)
 {
   LOCK_WORKER_SYNC_OBJECT(sync_object);
-  g_object_ref(G_OBJECT(sync_object));
+  OCHU_OBJECT_REF(G_OBJECT(sync_object));
   if (sync_object->poll_id == 0)
     {
       GIOChannel *channel = g_io_channel_unix_new(fd);
@@ -1195,7 +1195,7 @@ destruct_job_args(NetworkBrokerJobArgs *job_args)
     return;
 
   if (job_args->broker != NULL)
-    g_object_unref(G_OBJECT(job_args->broker));
+    OCHU_OBJECT_UNREF(G_OBJECT(job_args->broker));
 
   if (job_args->url != NULL)
     G_FREE(job_args->url);
@@ -1241,7 +1241,7 @@ ochusha_network_broker_worker_sync_object_free(WorkerSyncObject *sync_object)
   fprintf(stderr, "entering: sync_object_free(%p)\n", sync_object);
 #endif
 
-  g_object_unref(G_OBJECT(sync_object));
+  OCHU_OBJECT_UNREF(G_OBJECT(sync_object));
 }
 
 
@@ -1289,9 +1289,9 @@ ochusha_network_broker_employ_worker_thread(OchushaNetworkBroker *broker,
   job->args = buffer;
 
   /* åɤΤ˳ */
-  g_object_ref(G_OBJECT(sync_object));
-  g_object_ref(G_OBJECT(broker));
-  g_object_ref(G_OBJECT(buffer));
+  OCHU_OBJECT_REF(G_OBJECT(sync_object));
+  OCHU_OBJECT_REF(G_OBJECT(broker));
+  OCHU_OBJECT_REF(G_OBJECT(buffer));
 
   commit_job(job);
 
@@ -1337,7 +1337,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
       ochusha_async_buffer_fix(buffer);
       g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
-      g_object_unref(G_OBJECT(buffer));
+      OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 
       snprintf(message, LOG_MESSAGE_SIZE,
 	       _("Access terminated: %s\n"), url);
@@ -1819,7 +1819,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   ochusha_async_buffer_fix(buffer);
   ochusha_async_buffer_active_unref(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
-  g_object_unref(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
   return;
 
  error_exit:
@@ -1897,7 +1897,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   ochusha_async_buffer_fix(buffer);
   ochusha_async_buffer_active_unref(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
-  g_object_unref(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 }
 
 
@@ -2012,7 +2012,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
  finish_refresh_cache_after_read:
   ochusha_async_buffer_fix(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
-  g_object_unref(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 }
 
 
@@ -2071,7 +2071,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
  finish_force_read:
   ochusha_async_buffer_fix(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
-  g_object_unref(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 }
 
 
@@ -2120,8 +2120,8 @@ background_read_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
  finish_job:
   ochusha_async_buffer_fix(buffer);
-  g_object_unref(G_OBJECT(buffer));
-  g_object_unref(G_OBJECT(broker));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(broker));
 }
 
 
@@ -2204,8 +2204,8 @@ ochusha_network_broker_read_from_url(OchushaNetworkBroker *broker,
 	  job->job = (JobFunc *)background_read_cache;
 	  job->args = buffer;
 
-	  g_object_ref(G_OBJECT(broker));
-	  g_object_ref(G_OBJECT(buffer));
+	  OCHU_OBJECT_REF(G_OBJECT(broker));
+	  OCHU_OBJECT_REF(G_OBJECT(buffer));
 
 	  commit_job(job);
 
@@ -2555,7 +2555,7 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
  finish_force_read:
   ochusha_async_buffer_fix(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
-  g_object_unref(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 }
 
 
