@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_private.h,v 1.15 2003/12/19 21:34:57 fuyu Exp $
+ * $Id: ochusha_private.h,v 1.15.4.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_PRIVATE_H_
@@ -52,6 +52,9 @@
 #define DEBUG_POST		0
 #define DEBUG_POST_MOST		0
 
+#define DEBUG_REF_COUNT		0
+
+
 
 #include "utils.h"
 
@@ -75,9 +78,9 @@ extern "C" {
 # define bind_textdomain_codeset(Package, CodeSet)
 #endif
 
-#if TRACE_MEMORY_USAGE
 #include "utils.h"
 
+#if TRACE_MEMORY_USAGE
 static inline gpointer
 trace_g_malloc(gulong size, char *file, int line)
 {
@@ -180,6 +183,39 @@ trace_g_free(gpointer pointer, char *file, int line)
 #define G_FREE(pointer)			g_free(pointer)
 #endif
 
+
+#if DEBUG_REF_COUNT
+#define OCHU_OBJECT_REF(obj)						\
+  do									\
+    {									\
+      g_object_ref(obj);						\
+      fprintf(stderr,							\
+	      "g_object_ref(%p) at %s, line %d: ref_count=%d\n",	\
+	      obj, __FILE__, __LINE__, (obj)->ref_count);		\
+    } while (0)
+
+#define OCHU_OBJECT_UNREF(obj)						\
+  do									\
+    {									\
+      fprintf(stderr,							\
+	      "g_object_unref(%p) at %s, line %d: ref_count=%d\n",	\
+	      obj, __FILE__, __LINE__, (obj)->ref_count);		\
+      g_object_unref(obj);						\
+    } while (0)
+
+#define OCHU_OBJECT_REF_FUNC	ochu_object_ref
+#define OCHU_OBJECT_UNREF_FUNC	ochu_object_unref
+  
+#else
+
+#define OCHU_OBJECT_REF(obj)	g_object_ref(obj)
+#define OCHU_OBJECT_UNREF(obj)	g_object_unref(obj)
+#define OCHU_OBJECT_REF_FUNC	g_object_ref
+#define OCHU_OBJECT_UNREF_FUNC	g_object_unref
+
+#endif	/* DEBUG_REF_COUNT */
+
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
