@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.48 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.49.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -278,17 +278,18 @@ ochusha_thread_2ch_read_threadlist_element(OchushaBBSThread *thread,
 
 
 #define OUTPUT_THREAD_ATTRIBUTE_STRING(gzfile, thread, attribute)	\
-  do {									\
-    if ((thread)->attribute != NULL)					\
-      {									\
-        gchar *text = g_markup_escape_text((thread)->attribute, -1);	\
-        gzprintf(gzfile,						\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <string>%s</string>\n"				\
-	  "      </attribute>\n", text);				\
-        g_free(text);							\
-      }									\
-  } while (0)
+  do									\
+    {									\
+      if ((thread)->attribute != NULL)					\
+	{								\
+	  gchar *text = g_markup_escape_text((thread)->attribute, -1);	\
+	  gzprintf(gzfile,						\
+		   "      <attribute name=\"" #attribute	"\">\n"	\
+		   "        <string>%s</string>\n"			\
+		   "      </attribute>\n", text);			\
+	  g_free(text);							\
+	}								\
+    } while (0)
 
 
 static void
@@ -721,7 +722,7 @@ static gboolean
 advance_parsing(gpointer data)
 {
   ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
-  g_object_unref((GObject *)data);
+  OCHU_OBJECT_UNREF((GObject *)data);
   return FALSE;
 }
 
@@ -988,15 +989,16 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	      goto terminated;	/* ξ */
 
 	    if (ochusha_async_buffer_is_busy(buffer))
-	      do {
-		if (!ochusha_async_buffer_wait(buffer))
-		  {
+	      do
+		{
+		  if (!ochusha_async_buffer_wait(buffer))
+		    {
 #if DEBUG_ASYNC_BUFFER_MOST
-		    fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
+		      fprintf(stderr, "ochusha_thread_2ch_parse_responses(): buffer has been terminated.\n");
 #endif
-		    goto terminated;
-		  }
-	      } while (buffer->length == old_len && !buffer->fixed);
+		      goto terminated;
+		    }
+		} while (buffer->length == old_len && !buffer->fixed);
 	  }
 	else
 	  {
@@ -1014,7 +1016,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		/*
 		 * GUIΥ쥹ݥ󥹤βܻؤ¸
 		 */
-		g_object_ref(buffer);
+		OCHU_OBJECT_REF(G_OBJECT(buffer));
 		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
 				advance_parsing, buffer, NULL);
 		if (!ochusha_async_buffer_wait(buffer))
