@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.17 2003/12/21 18:36:13 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.18.2.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -430,7 +430,7 @@ static gboolean
 advance_parsing(gpointer data)
 {
   ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
-  g_object_unref((GObject *)data);
+  OCHU_OBJECT_UNREF((GObject *)data);
   return FALSE;
 }
 
@@ -672,15 +672,16 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	      goto terminated;	/* ξ */
 
 	    if (ochusha_async_buffer_is_busy(buffer))
-	      do {
-		if (!ochusha_async_buffer_wait(buffer))
-		  {
+	      do
+		{
+		  if (!ochusha_async_buffer_wait(buffer))
+		    {
 #if DEBUG_ASYNC_BUFFER_MOST
-		    fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
+		      fprintf(stderr, "ochusha_thread_jbbs_parse_responses(): buffer has been terminated.\n");
 #endif
-		    goto terminated;
-		  }
-	      } while (buffer->length == old_len && !buffer->fixed);
+		      goto terminated;
+		    }
+		} while (buffer->length == old_len && !buffer->fixed);
 	  }
 	else
 	  {
@@ -698,7 +699,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 		/*
 		 * GUIΥ쥹ݥ󥹤βܻؤ¸
 		 */
-		g_object_ref(buffer);
+		OCHU_OBJECT_REF(G_OBJECT(buffer));
 		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
 				advance_parsing, buffer, NULL);
 		if (!ochusha_async_buffer_wait(buffer))
@@ -1491,8 +1492,8 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
     regex_free(response_pattern);
   if (match_region != NULL)
     regex_region_free(match_region, 1);
-  g_object_unref(G_OBJECT(dat_buffer));
-  g_object_unref(G_OBJECT(args->broker));
+  OCHU_OBJECT_UNREF(G_OBJECT(dat_buffer));
+  OCHU_OBJECT_UNREF(G_OBJECT(args->broker));
 }
 
 
@@ -1503,7 +1504,7 @@ unref_html_buffer(OchushaAsyncBuffer *html_buffer)
 #if DEBUG_OCHUSHA_ASYNC_BUFFER_MOST
   fprintf(stderr, "unref_html_buffer: %p\n", html_buffer);
 #endif
-  g_object_unref(html_buffer);
+  OCHU_OBJECT_UNREF(G_OBJECT(html_buffer));
 }
 
 
@@ -1672,8 +1673,8 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
   job->args = args;
 
   /* åɤΤ˳ */
-  g_object_ref(G_OBJECT(dat_buffer));
-  g_object_ref(G_OBJECT(broker));
+  OCHU_OBJECT_REF(G_OBJECT(dat_buffer));
+  OCHU_OBJECT_REF(G_OBJECT(broker));
 
   commit_job(job);
 
