@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.26 2003/12/19 03:13:38 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.26.4.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -766,7 +766,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	  /* ФΥ롼ľηǼĤϸʤġġ*/
 	  if (id == NULL || id[0] == '\0')
 	    {
-	      g_object_unref(G_OBJECT(board));
+	      OCHU_OBJECT_UNREF(G_OBJECT(board));
 	      board = NULL;
 	      goto search_next;
 	    }
@@ -786,7 +786,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      if (winner == board_by_name)
 		{
 		  /* boardϥơ֥ɲäʤ */
-		  g_object_unref(G_OBJECT(board));
+		  OCHU_OBJECT_UNREF(G_OBJECT(board));
 		  board = NULL;
 		  goto search_next;
 		}
@@ -807,12 +807,12 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 							   callback_data);
 		  if (!result)
 		    {
-		      g_object_unref(G_OBJECT(board));
+		      OCHU_OBJECT_UNREF(G_OBJECT(board));
 		      return FALSE;
 		    }
 		}
 	      ochusha_bbs_table_add_board(table, board);
-	      g_object_unref(G_OBJECT(board));
+	      OCHU_OBJECT_UNREF(G_OBJECT(board));
 	    }
 	}
 
@@ -947,7 +947,7 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 				    callback_data);
 
 	    if (!result || category->board_list == NULL)
-	      g_object_unref(G_OBJECT(category));
+	      OCHU_OBJECT_UNREF(G_OBJECT(category));
 	    else
 	      {
 		category->killed = FALSE;
