@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.16 2003/12/18 14:07:43 fuyu Exp $
+ * $Id: utils.c,v 1.16.4.1 2003/12/29 09:04:39 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION
@@ -1627,6 +1627,22 @@ cp932_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
 }
 
 
+#if DEBUG_REF_COUNT
+void
+ochu_object_ref(GObject *object)
+{
+  OCHU_OBJECT_REF(object);
+}
+
+
+void
+ochu_object_unref(GObject *object)
+{
+  OCHU_OBJECT_UNREF(object);
+}
+#endif
+
+
 #if TRACE_MEMORY_USAGE
 /*
  * ꡼åϢ
